# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM signature/authentication error
AUTHFAILURE = 'AuthFailure'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# The CMK is being used by a Tencent Cloud product.
FAILEDOPERATION_CMKUSEDBYCLOUDPRODUCT = 'FailedOperation.CmkUsedByCloudProduct'

# Decryption failed.
FAILEDOPERATION_DECRYPTERROR = 'FailedOperation.DecryptError'

# Encryption failed.
FAILEDOPERATION_ENCRYPTIONERROR = 'FailedOperation.EncryptionError'

# 
FAILEDOPERATION_TAGGINGERROR = 'FailedOperation.TaggingError'

# Internal error.
INTERNALERROR = 'InternalError'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Decryption of `EncryptedKeyMaterial` failed.
INVALIDPARAMETER_DECRYPTMATERIALERROR = 'InvalidParameter.DecryptMaterialError'

# The schedule deletion time parameter is invalid.
INVALIDPARAMETER_INVALIDPENDINGWINDOWINDAYS = 'InvalidParameter.InvalidPendingWindowInDays'

# Incorrect parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# The alias already exists.
INVALIDPARAMETERVALUE_ALIASALREADYEXISTS = 'InvalidParameterValue.AliasAlreadyExists'

# Duplicate `KeyId`.
INVALIDPARAMETERVALUE_DUPLICATEDKEYID = 'InvalidParameterValue.DuplicatedKeyId'

# Incorrect alias format
INVALIDPARAMETERVALUE_INVALIDALIAS = 'InvalidParameterValue.InvalidAlias'

# Incorrect ciphertext format
INVALIDPARAMETERVALUE_INVALIDCIPHERTEXT = 'InvalidParameterValue.InvalidCiphertext'

# Invalid HSM cluster ID.
INVALIDPARAMETERVALUE_INVALIDHSMCLUSTERID = 'InvalidParameterValue.InvalidHsmClusterId'

# Invalid `KeyId`.
INVALIDPARAMETERVALUE_INVALIDKEYID = 'InvalidParameterValue.InvalidKeyId'

# Incorrect `KeyUsage` parameter.
INVALIDPARAMETERVALUE_INVALIDKEYUSAGE = 'InvalidParameterValue.InvalidKeyUsage'

# Invalid `Plaintext`.
INVALIDPARAMETERVALUE_INVALIDPLAINTEXT = 'InvalidParameterValue.InvalidPlaintext'

# Incorrect `Type` parameter.
INVALIDPARAMETERVALUE_INVALIDTYPE = 'InvalidParameterValue.InvalidType'

# The key material is different from the one previously imported.
INVALIDPARAMETERVALUE_MATERIALNOTMATCH = 'InvalidParameterValue.MaterialNotMatch'

# Duplicate tag key.
INVALIDPARAMETERVALUE_TAGKEYSDUPLICATED = 'InvalidParameterValue.TagKeysDuplicated'

# The tag key or tag value does not exist.
INVALIDPARAMETERVALUE_TAGSNOTEXISTED = 'InvalidParameterValue.TagsNotExisted'

# The number of CMKs has reached the upper limit.
LIMITEXCEEDED_CMKLIMITEXCEEDED = 'LimitExceeded.CmkLimitExceeded'

# The number of device fingerprints exceeded the limit.
LIMITEXCEEDED_FINGERPRINTSLIMITEXCEEDED = 'LimitExceeded.FingerprintsLimitExceeded'

# The number of created keys exceeded the limit.
LIMITEXCEEDED_KEYLIMITEXCEEDED = 'LimitExceeded.KeyLimitExceeded'

# Missing parameters. Please check and try again.
MISSINGPARAMETER = 'MissingParameter'

# The resource does not exist.
RESOURCENOTFOUND = 'ResourceNotFound'

# The CMK is not bound with the Tencent Cloud resource
RESOURCEUNAVAILABLE_CLOUDRESOURCEBINDINGNOTFOUND = 'ResourceUnavailable.CloudResourceBindingNotFound'

# The CMK has been archived.
RESOURCEUNAVAILABLE_CMKARCHIVED = 'ResourceUnavailable.CmkArchived'

# The CMK has been disabled.
RESOURCEUNAVAILABLE_CMKDISABLED = 'ResourceUnavailable.CmkDisabled'

# The CMK does not exist.
RESOURCEUNAVAILABLE_CMKNOTFOUND = 'ResourceUnavailable.CmkNotFound'

# As the CMK is not scheduled for deletion, you cannot cancel the schedule deletion.
RESOURCEUNAVAILABLE_CMKNOTPENDINGDELETE = 'ResourceUnavailable.CmkNotPendingDelete'

# An enabled CMK cannot be scheduled for deletion.
RESOURCEUNAVAILABLE_CMKSHOULDBEDISABLED = 'ResourceUnavailable.CmkShouldBeDisabled'

# This operation cannot be performed under the current CMK status.
RESOURCEUNAVAILABLE_CMKSTATENOTSUPPORT = 'ResourceUnavailable.CmkStateNotSupport'

# The key has been disabled.
RESOURCEUNAVAILABLE_KEYDISABLED = 'ResourceUnavailable.KeyDisabled'

# The key is not available as it’s pending deleted.
RESOURCEUNAVAILABLE_KEYPENDINGDELETE = 'ResourceUnavailable.KeyPendingDelete'

# The white-box key service has not been activated.
RESOURCEUNAVAILABLE_NOTPURCHASED = 'ResourceUnavailable.NotPurchased'

# Token has expired.
RESOURCEUNAVAILABLE_TOKENEXPIRED = 'ResourceUnavailable.TokenExpired'

# Unauthorized operation.
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# External CMKs cannot be rotated.
UNSUPPORTEDOPERATION_EXTERNALCMKCANNOTROTATE = 'UnsupportedOperation.ExternalCmkCanNotRotate'

# Incorrect CMK type. Only `External` CMKs are supported.
UNSUPPORTEDOPERATION_NOTEXTERNALCMK = 'UnsupportedOperation.NotExternalCmk'

# You can only update the CMKs created by you.
UNSUPPORTEDOPERATION_NOTUSERCREATEDCMK = 'UnsupportedOperation.NotUserCreatedCmk'

# The service is temporarily unavailable.
UNSUPPORTEDOPERATION_SERVICETEMPORARYUNAVAILABLE = 'UnsupportedOperation.ServiceTemporaryUnavailable'

# The encryption method is not supported in the current region.
UNSUPPORTEDOPERATION_UNSUPPORTEDKEYUSAGEINCURRENTREGION = 'UnsupportedOperation.UnsupportedKeyUsageInCurrentRegion'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM signature/authentication error.
AUTHFAILURE = 'AuthFailure'

# Invalid authorization.
AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'

# Failed to add the security group information of the instance.
FAILEDOPERATION_ADDINSTANCEINFOFAILED = 'FailedOperation.AddInstanceInfoFailed'

# Failed to associate the security group.
FAILEDOPERATION_ASSOCIATESECURITYGROUPSFAILED = 'FailedOperation.AssociateSecurityGroupsFailed'

# Failed to clear the security group information of the instance.
FAILEDOPERATION_CLEARINSTANCEINFOFAILED = 'FailedOperation.ClearInstanceInfoFailed'

# Failed to submit the task.
FAILEDOPERATION_COMMITFLOWERROR = 'FailedOperation.CommitFlowError'

# Failed to unbind the security group.
FAILEDOPERATION_DISASSOCIATESECURITYGROUPSFAILED = 'FailedOperation.DisassociateSecurityGroupsFailed'

# This operation is not allowed under the current DTS status.
FAILEDOPERATION_DTSSTATUSABNORMAL = 'FailedOperation.DtsStatusAbnormal'

# No process exists.
FAILEDOPERATION_FLOWNOTEXISTS = 'FailedOperation.FlowNotExists'

# Failed to query the security group details. Try again later.
FAILEDOPERATION_GETSECURITYGROUPDETAILFAILED = 'FailedOperation.GetSecurityGroupDetailFailed'

# Payment failed.
FAILEDOPERATION_PAYFAILED = 'FailedOperation.PayFailed'

# No exact description for this error code for the time being.
FAILEDOPERATION_REDOFLOWFAILED = 'FailedOperation.RedoFlowFailed'

# Failed to set the rule.
FAILEDOPERATION_SETRULELOCATIONFAILED = 'FailedOperation.SetRuleLocationFailed'

# Internal system error, which is irrelevant to the business.
FAILEDOPERATION_SYSTEMERROR = 'FailedOperation.SystemError'

# The instance does not support this API.
FAILEDOPERATION_UNSUPPORTERROR = 'FailedOperation.UnSupportError'

# Invalid data is entered for weekday.
FAILEDOPERATION_UNKNOWN = 'FailedOperation.Unknown'

# Failed to update the security group information of the instance.
FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFailed'

# Failed to update the security group.
FAILEDOPERATION_UPDATESECURITYGROUPSFAILED = 'FailedOperation.UpdateSecurityGroupsFailed'

# Internal error.
INTERNALERROR = 'InternalError'

# A CAM authentication error occurred.
INTERNALERROR_CAMAUTHOSSRESPONSERETURNCODEERROR = 'InternalError.CamAuthOssResponseReturnCodeError'

# Internal system error with the database operation, which may be update, insert, select, etc.
INTERNALERROR_DBOPERATIONFAILED = 'InternalError.DbOperationFailed'

# Failed to execute the HTTP request. Try again later.
INTERNALERROR_EXECHTTPREQUESTERROR = 'InternalError.ExecHttpRequestError'

# You do not have the operation permission.
INTERNALERROR_INSTANCEOPERATEPERMISSIONERROR = 'InternalError.InstanceOperatePermissionError'

# Internal error.
INTERNALERROR_INTERNALERROR = 'InternalError.InternalError'

# An error occurred while obtaining the list of instances. Try again later.
INTERNALERROR_LISTINSTANCESERROR = 'InternalError.ListInstancesError'

# A network error occurred.
INTERNALERROR_NETWORKERR = 'InternalError.NetWorkErr'

# Incorrect parameter.
INVALIDPARAMETER = 'InvalidParameter'

# The corresponding API was not found.
INVALIDPARAMETER_ACTIONNOTFOUND = 'InvalidParameter.ActionNotFound'

# The parameter is empty.
INVALIDPARAMETER_EMPTYPARAM = 'InvalidParameter.EmptyParam'

# Invalid parameter.
INVALIDPARAMETER_ILLEGALPARAMETERERROR = 'InvalidParameter.IllegalParameterError'

# The security groups of the instance exceeds the limit.
INVALIDPARAMETER_INSTANCESGOVERLIMITERROR = 'InvalidParameter.InstanceSGOverLimitError'

# Invalid service parameter.
INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'

# The operation is unsupported due to incorrect parameters.
INVALIDPARAMETER_NOTSUPPORTED = 'InvalidParameter.NotSupported'

# Only VPCs are provided in the Shanghai Finance AZ.
INVALIDPARAMETER_ONLYVPCONSPECZONEID = 'InvalidParameter.OnlyVPCOnSpecZoneId'

# The time format or time range is invalid.
INVALIDPARAMETER_PERIOD = 'InvalidParameter.Period'

# The API has no CAM permissions.
INVALIDPARAMETER_PERMISSIONDENIED = 'InvalidParameter.PermissionDenied'

# Incorrect parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# The backup does not exist.
INVALIDPARAMETERVALUE_BACKUPNOTEXISTS = 'InvalidParameterValue.BackupNotExists'

# The instance is not in a VPC.
INVALIDPARAMETERVALUE_BASENETWORKACCESSDENY = 'InvalidParameterValue.BaseNetWorkAccessDeny'

# The type of instances requested for purchase is incorrect (TypeId - 1: Cluster Edition; 2: Master-Replica Edition, i.e., the legacy Master-Replica Edition).
INVALIDPARAMETERVALUE_INVALIDINSTANCETYPEID = 'InvalidParameterValue.InvalidInstanceTypeId'

# The `vpcid` or subnet ID in the VPC is invalid.
INVALIDPARAMETERVALUE_INVALIDSUBNETID = 'InvalidParameterValue.InvalidSubnetId'

# The requested capacity is out of the purchasable capacity range.
INVALIDPARAMETERVALUE_MEMSIZENOTINRANGE = 'InvalidParameterValue.MemSizeNotInRange'

# The password is empty.
INVALIDPARAMETERVALUE_PASSWORDEMPTY = 'InvalidParameterValue.PasswordEmpty'

# Password verification error due to incorrect password.
INVALIDPARAMETERVALUE_PASSWORDERROR = 'InvalidParameterValue.PasswordError'

# Tencent internal accounts are not allowed to use password-free instances.
INVALIDPARAMETERVALUE_PASSWORDFREEDENIED = 'InvalidParameterValue.PasswordFreeDenied'

# When the password is set, the old password passed in by MC does not match the previously set password.
INVALIDPARAMETERVALUE_PASSWORDRULEERROR = 'InvalidParameterValue.PasswordRuleError'

# The request capacity is too small. Capacity reduction is not supported.
INVALIDPARAMETERVALUE_REDUCECAPACITYNOTALLOWED = 'InvalidParameterValue.ReduceCapacityNotAllowed'

# The global replication group doesn’t exist.
INVALIDPARAMETERVALUE_REPLICATIONGROUPNOTEXISTS = 'InvalidParameterValue.ReplicationGroupNotExists'

# The request parameter or security group ID is incorrect.
INVALIDPARAMETERVALUE_SECURITYGROUPIDSNOTEXISTS = 'InvalidParameterValue.SecurityGroupIdsNotExists'

# The instance specification doesn’t exist.
INVALIDPARAMETERVALUE_SPECNOTEXIST = 'InvalidParameterValue.SpecNotExist'

# The instance type is not supported.
INVALIDPARAMETERVALUE_UNSUPPORTEDTYPE = 'InvalidParameterValue.UnSupportedType'

# The `uniqVpcId` or subnet ID in the VPC is invalid.
INVALIDPARAMETERVALUE_UNVPCIDNOTEXISTS = 'InvalidParameterValue.UnVpcIdNotExists'

# Invalid data is entered for `weekday`.
INVALIDPARAMETERVALUE_WEEKDAYSISINVALID = 'InvalidParameterValue.WeekDaysIsInvalid'

# The quota limit has been reached.
LIMITEXCEEDED = 'LimitExceeded'

# The requested capacity is out of the purchasable specification range (`memSize` should be an integer multiple of 1,024 in MB).
LIMITEXCEEDED_INVALIDMEMSIZE = 'LimitExceeded.InvalidMemSize'

# The number of instances requested for purchase at a time is out of the purchasable quantity range.
LIMITEXCEEDED_INVALIDPARAMETERGOODSNUMNOTINRANGE = 'LimitExceeded.InvalidParameterGoodsNumNotInRange'

# The requested capacity is out of the purchasable capacity range.
LIMITEXCEEDED_MEMSIZENOTINRANGE = 'LimitExceeded.MemSizeNotInRange'

# The requested length of purchase is more than three years and exceeds the maximum value.
LIMITEXCEEDED_PERIODEXCEEDMAXLIMIT = 'LimitExceeded.PeriodExceedMaxLimit'

# The length of purchase is invalid. It must be at least one month.
LIMITEXCEEDED_PERIODLESSTHANMINLIMIT = 'LimitExceeded.PeriodLessThanMinLimit'

# The instance is locked by another process.
RESOURCEINUSE_INSTANCEBEENLOCKED = 'ResourceInUse.InstanceBeenLocked'

# The resource is insufficient.
RESOURCEINSUFFICIENT = 'ResourceInsufficient'

# The resource doesn’t exist.
RESOURCENOTFOUND = 'ResourceNotFound'

# The UIN value is empty.
RESOURCENOTFOUND_ACCOUNTDOESNOTEXISTS = 'ResourceNotFound.AccountDoesNotExists'

# No Redis instance is found by the serialId.
RESOURCENOTFOUND_INSTANCENOTEXISTS = 'ResourceNotFound.InstanceNotExists'

# The instance was not found.
RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'

# The request order number does not exist.
RESOURCEUNAVAILABLE_ACCOUNTBALANCENOTENOUGH = 'ResourceUnavailable.AccountBalanceNotEnough'

# The backup has been locked by another task, and the operation cannot be performed temporarily.
RESOURCEUNAVAILABLE_BACKUPLOCKEDERROR = 'ResourceUnavailable.BackupLockedError'

# Backup status exception. The operation cannot be performed temporarily. The backup may have expired or been deleted.
RESOURCEUNAVAILABLE_BACKUPSTATUSABNORMAL = 'ResourceUnavailable.BackupStatusAbnormal'

# Failed to call the backend API.
RESOURCEUNAVAILABLE_CALLOSSERROR = 'ResourceUnavailable.CallOssError'

# Failed to get the security group information.
RESOURCEUNAVAILABLE_GETSECURITYERROR = 'ResourceUnavailable.GetSecurityError'

# An instance configuration error occurred.
RESOURCEUNAVAILABLE_INSTANCECONFERROR = 'ResourceUnavailable.InstanceConfError'

# The instance has already been repossessed.
RESOURCEUNAVAILABLE_INSTANCEDELETED = 'ResourceUnavailable.InstanceDeleted'

# The instance has expired.
RESOURCEUNAVAILABLE_INSTANCEISOLATED = 'ResourceUnavailable.InstanceIsolated'

# Redis has been locked by another process.
RESOURCEUNAVAILABLE_INSTANCELOCKEDERROR = 'ResourceUnavailable.InstanceLockedError'

# The order does not exist.
RESOURCEUNAVAILABLE_INSTANCENODEAL = 'ResourceUnavailable.InstanceNoDeal'

# Instances in this status do not support the operation.
RESOURCEUNAVAILABLE_INSTANCENOTSUPPORTOPERATION = 'ResourceUnavailable.InstanceNotSupportOperation'

# Instance status error.
RESOURCEUNAVAILABLE_INSTANCESTATEERROR = 'ResourceUnavailable.InstanceStateError'

# The Redis status is exceptional, and the corresponding process cannot be executed.
RESOURCEUNAVAILABLE_INSTANCESTATUSABNORMAL = 'ResourceUnavailable.InstanceStatusAbnormal'

# Operation unsupported: the instance is exceptional.
RESOURCEUNAVAILABLE_INSTANCESTATUSERROR = 'ResourceUnavailable.InstanceStatusError'

# The instance has been locked by another process.
RESOURCEUNAVAILABLE_INSTANCEUNLOCKEDERROR = 'ResourceUnavailable.InstanceUnLockedError'

# The IP resources in the VPC are insufficient.
RESOURCEUNAVAILABLE_NOENOUGHVIPINVPC = 'ResourceUnavailable.NoEnoughVipInVPC'

# The requested region currently does not provide the Redis service.
RESOURCEUNAVAILABLE_NOREDISSERVICE = 'ResourceUnavailable.NoRedisService'

# The requested region currently does not provide the requested type of Redis service.
RESOURCEUNAVAILABLE_NOTYPEIDREDISSERVICE = 'ResourceUnavailable.NoTypeIdRedisService'

# Resources of the specified type in the region are sold out.
RESOURCEUNAVAILABLE_SALEOUT = 'ResourceUnavailable.SaleOut'

# The product has not been connected to any security group.
RESOURCEUNAVAILABLE_SECURITYGROUPNOTSUPPORTED = 'ResourceUnavailable.SecurityGroupNotSupported'

# The operation is unauthorized.
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# No CAM permissions.
UNAUTHORIZEDOPERATION_NOCAMAUTHED = 'UnauthorizedOperation.NoCAMAuthed'

# The user is not in the allowlist.
UNAUTHORIZEDOPERATION_USERNOTINWHITELIST = 'UnauthorizedOperation.UserNotInWhiteList'

# The operation is not supported.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# The Redis cluster edition is not allowed to connect to a security group.
UNSUPPORTEDOPERATION_CLUSTERINSTANCEACCESSEDDENY = 'UnsupportedOperation.ClusterInstanceAccessedDeny'

# Unsupported operation
UNSUPPORTEDOPERATION_INSTANCENOTOPERATION = 'UnsupportedOperation.InstanceNotOperation'

# There is an error with the auto-renewal flag.
UNSUPPORTEDOPERATION_ISAUTORENEWERROR = 'UnsupportedOperation.IsAutoRenewError'

# Only Cluster Edition instances support backup exporting.
UNSUPPORTEDOPERATION_ONLYCLUSTERINSTANCECANEXPORTBACKUP = 'UnsupportedOperation.OnlyClusterInstanceCanExportBackup'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Error with CAM signature/authentication.
AUTHFAILURE = 'AuthFailure'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Failed to create the image.
FAILEDOPERATION_CREATEBLUEPRINTFAILED = 'FailedOperation.CreateBlueprintFailed'

# Failed to create the key pair.
FAILEDOPERATION_CREATEKEYPAIRFAILED = 'FailedOperation.CreateKeyPairFailed'

# Failed to delete the key pair.
FAILEDOPERATION_DELETEKEYPAIRFAILED = 'FailedOperation.DeleteKeyPairFailed'

# Failed to manipulate the firewall rule.
FAILEDOPERATION_FIREWALLRULESOPERATIONFAILED = 'FailedOperation.FirewallRulesOperationFailed'

# Failed to import the key pair.
FAILEDOPERATION_IMPORTKEYPAIRFAILED = 'FailedOperation.ImportKeyPairFailed'

# Failed to manipulate the instance.
FAILEDOPERATION_INSTANCEOPERATIONFAILED = 'FailedOperation.InstanceOperationFailed'

# Failed to manipulate the snapshot.
FAILEDOPERATION_SNAPSHOTOPERATIONFAILED = 'FailedOperation.SnapshotOperationFailed'

# The operation failed. The custom image could not be created.
FAILEDOPERATION_UNABLETOCREATEBLUEPRINT = 'FailedOperation.UnableToCreateBlueprint'

# Failed to create the instance
FAILEDOPERATION_UNABLETOCREATEINSTANCES = 'FailedOperation.UnableToCreateInstances'

# Internal error.
INTERNALERROR = 'InternalError'

# The disk query returned invalid content.
INTERNALERROR_DESCRIBEDISKSRETURNABLEERROR = 'InternalError.DescribeDisksReturnableError'

# Failed to query the instance status. Please try again later.
INTERNALERROR_DESCRIBEINSTANCESTATUS = 'InternalError.DescribeInstanceStatus'

# Failed to query whether the configuration of the instance can be modified.
INTERNALERROR_DESCRIBEINSTANCESMODIFICATION = 'InternalError.DescribeInstancesModification'

# Failed to query whether the configuration of the instance can be modified.
INTERNALERROR_DESCRIBEINSTANCESMODIFICATIONERROR = 'InternalError.DescribeInstancesModificationError'

# Failed to query whether the instance can be returned.
INTERNALERROR_DESCRIBEINSTANCESRETURNABLEERROR = 'InternalError.DescribeInstancesReturnableError'

# An error occurred while querying the instance traffic package.
INTERNALERROR_DESCRIBEINSTANCESTRAFFICPACKAGESFAILED = 'InternalError.DescribeInstancesTrafficPackagesFailed'

# Failed to get the snapshot quota lock.
INTERNALERROR_GETSNAPSHOTALLOCQUOTALOCKERROR = 'InternalError.GetSnapshotAllocQuotaLockError'

# Failed to find this API
INTERNALERROR_INVALIDACTIONNOTFOUND = 'InternalError.InvalidActionNotFound'

# The package price is incorrect.
INTERNALERROR_INVALIDBUNDLEPRICE = 'InternalError.InvalidBundlePrice'

# The command `DescribeInstanceLoginKeyPair` could not be found.
INTERNALERROR_INVALIDCOMMANDNOTFOUND = 'InternalError.InvalidCommandNotFound'

# There was an error in the request.
INTERNALERROR_REQUESTERROR = 'InternalError.RequestError'

# Failed to call billing gateway service
INTERNALERROR_TRADECALLBILLINGGATEWAYFAILED = 'InternalError.TradeCallBillingGatewayFailed'

# Failed to get the price.
INTERNALERROR_TRADEGETPRICEFAILED = 'InternalError.TradeGetPriceFailed'

# Incorrect parameter.
INVALIDPARAMETER = 'InvalidParameter'

# The package and the image do not match.
INVALIDPARAMETER_BUNDLEANDBLUEPRINTNOTMATCH = 'InvalidParameter.BundleAndBlueprintNotMatch'

# Undefined service package ID.
INVALIDPARAMETER_BUNDLEIDNOTFOUND = 'InvalidParameter.BundleIdNotFound'

# Invalid parameter: the number of `Values` in the `Filter` parameter exceeds the allowed maximum number.
INVALIDPARAMETER_FILTERVALUELIMITEXCEEDED = 'InvalidParameter.FilterValueLimitExceeded'

# Invalid parameter: the firewall rule is duplicated.
INVALIDPARAMETER_FIREWALLRULESDUPLICATED = 'InvalidParameter.FirewallRulesDuplicated'

# Invalid parameter: the firewall rule already exists.
INVALIDPARAMETER_FIREWALLRULESEXIST = 'InvalidParameter.FirewallRulesExist'

# Invalid parameter: the `Filter` parameter is invalid.
INVALIDPARAMETER_INVALIDFILTER = 'InvalidParameter.InvalidFilter'

# Invalid parameter: the value of `Name` in the `Filter` parameter is invalid.
INVALIDPARAMETER_INVALIDFILTERINVALIDKEY = 'InvalidParameter.InvalidFilterInvalidKey'

# Invalid parameter: the value of `Name` in the `Filter` parameter is not a string.
INVALIDPARAMETER_INVALIDFILTERINVALIDNAMENOTSTR = 'InvalidParameter.InvalidFilterInvalidNameNotStr'

# Invalid parameter: the `Values` in the `Filter` parameter is not a list.
INVALIDPARAMETER_INVALIDFILTERINVALIDVALUESNOTLIST = 'InvalidParameter.InvalidFilterInvalidValuesNotList'

# Invalid parameter: the `Filter` parameter is not a dictionary.
INVALIDPARAMETER_INVALIDFILTERNOTDICT = 'InvalidParameter.InvalidFilterNotDict'

# Invalid parameter: there are unsupported `Name` values in the `Filter` parameter.
INVALIDPARAMETER_INVALIDFILTERNOTSUPPORTEDNAME = 'InvalidParameter.InvalidFilterNotSupportedName'

# Invalid parameter: only one attribute can be modified at a time.
INVALIDPARAMETER_ONLYALLOWMODIFYONEATTRIBUTE = 'InvalidParameter.OnlyAllowModifyOneAttribute'

# Invalid parameter: the parameters conflict.
INVALIDPARAMETER_PARAMETERCONFLICT = 'InvalidParameter.ParameterConflict'

# Incorrect parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# The configuration of this instance does not meet the requirements of the specified image.
INVALIDPARAMETERVALUE_BLUEPRINTCONFIGNOTMATCH = 'InvalidParameterValue.BlueprintConfigNotMatch'

# The image ID is invalid, as instance reinstallation does not allow switching the OS type.
INVALIDPARAMETERVALUE_BLUEPRINTID = 'InvalidParameterValue.BlueprintId'

# Invalid parameter value: the image ID format is invalid.
INVALIDPARAMETERVALUE_BLUEPRINTIDMALFORMED = 'InvalidParameterValue.BlueprintIdMalformed'

# The ID format of the CCN instance is invalid.
INVALIDPARAMETERVALUE_CCNIDMALFORMED = 'InvalidParameterValue.CcnIdMalformed'

# The disk name is too long.
INVALIDPARAMETERVALUE_DISKNAMETOOLONG = 'InvalidParameterValue.DiskNameTooLong'

# The disk size has changed.
INVALIDPARAMETERVALUE_DISKSIZENOTMATCH = 'InvalidParameterValue.DiskSizeNotMatch'

# The parameter `KeyName` already exists and is duplicate.
INVALIDPARAMETERVALUE_DUPLICATEPARAMETERVALUE = 'InvalidParameterValue.DuplicateParameterValue'

# Invalid parameter value: duplicate values are not allowed.
INVALIDPARAMETERVALUE_DUPLICATED = 'InvalidParameterValue.Duplicated'

# The length of the firewall rule description exceeds the limit.
INVALIDPARAMETERVALUE_FIREWALLRULEDESCRIPTIONTOOLONG = 'InvalidParameterValue.FirewallRuleDescriptionTooLong'

# Invalid parameter value: the instance ID format is invalid.
INVALIDPARAMETERVALUE_INSTANCEIDMALFORMED = 'InvalidParameterValue.InstanceIdMalformed'

# Invalid parameter value: the length of the instance name exceeds the upper limit.
INVALIDPARAMETERVALUE_INSTANCENAMETOOLONG = 'InvalidParameterValue.InstanceNameTooLong'

# The image ID is invalid.
INVALIDPARAMETERVALUE_INVALIDBLUEPRINTID = 'InvalidParameterValue.InvalidBlueprintId'

# The type of the image OS is invalid.
INVALIDPARAMETERVALUE_INVALIDBLUEPRINTPLATFORMTYPE = 'InvalidParameterValue.InvalidBlueprintPlatformType'

# Invalid image status value
INVALIDPARAMETERVALUE_INVALIDBLUEPRINTSTATE = 'InvalidParameterValue.InvalidBlueprintState'

# The image type is invalid.
INVALIDPARAMETERVALUE_INVALIDBLUEPRINTTYPE = 'InvalidParameterValue.InvalidBlueprintType'

# Invalid package parameter.
INVALIDPARAMETERVALUE_INVALIDBUNDLE = 'InvalidParameterValue.InvalidBundle'

# The console display type is invalid.
INVALIDPARAMETERVALUE_INVALIDCONSOLEDISPLAYTYPES = 'InvalidParameterValue.InvalidConsoleDisplayTypes'

# Invalid parameter value: the disk ID format is invalid.
INVALIDPARAMETERVALUE_INVALIDDISKIDMALFORMED = 'InvalidParameterValue.InvalidDiskIdMalformed'

# The value of setting whether to use the default key pair for login is incorrect.
INVALIDPARAMETERVALUE_INVALIDINSTANCELOGINKEYPAIRPERMITLOGIN = 'InvalidParameterValue.InvalidInstanceLoginKeyPairPermitLogin'

# Invalid parametric value: the IP address format is invalid.
INVALIDPARAMETERVALUE_INVALIDIPFORMAT = 'InvalidParameterValue.InvalidIpFormat'

# Invalid parametric value.
INVALIDPARAMETERVALUE_INVALIDKEYPAIRNAMEEMPTY = 'InvalidParameterValue.InvalidKeyPairNameEmpty'

# The key pair name is invalid.
INVALIDPARAMETERVALUE_INVALIDKEYPAIRNAMEINCLUDEILLEGALCHAR = 'InvalidParameterValue.InvalidKeyPairNameIncludeIllegalChar'

# The parameter length is invalid.
INVALIDPARAMETERVALUE_INVALIDKEYPAIRNAMETOOLONG = 'InvalidParameterValue.InvalidKeyPairNameTooLong'

# Invalid package combination.
INVALIDPARAMETERVALUE_INVALIDPARAMETERCOMBINATION = 'InvalidParameterValue.InvalidParameterCombination'

# The password in the parameter is invalid.
INVALIDPARAMETERVALUE_INVALIDPASSWORD = 'InvalidParameterValue.InvalidPassword'

# Incorrect quota resource name.
INVALIDPARAMETERVALUE_INVALIDRESOURCEQUOTARESOURCENAME = 'InvalidParameterValue.InvalidResourceQuotaResourceName'

# Invalid `Zone` value.
INVALIDPARAMETERVALUE_INVALIDZONE = 'InvalidParameterValue.InvalidZone'

# Invalid parametric value: the key pair ID format is invalid.
INVALIDPARAMETERVALUE_KEYPAIRIDMALFORMED = 'InvalidParameterValue.KeyPairIdMalformed'

# The public key of this key pair already exists in the system and cannot be reused.
INVALIDPARAMETERVALUE_KEYPAIRPUBLICKEYDUPLICATED = 'InvalidParameterValue.KeyPairPublicKeyDuplicated'

# The format of the specified public key is incorrect.
INVALIDPARAMETERVALUE_KEYPAIRPUBLICKEYMALFORMED = 'InvalidParameterValue.KeyPairPublicKeyMalformed'

# Invalid parametric value: the number of parameter values exceeds the upper limit.
INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'

# Invalid parametric value: it cannot be negative.
INVALIDPARAMETERVALUE_NEGATIVE = 'InvalidParameterValue.Negative'

# It is not allowed to change the OS type.
INVALIDPARAMETERVALUE_NOTALLOWTOCHANGEPLATFORMTYPE = 'InvalidParameterValue.NotAllowToChangePlatformType'

# Invalid parametric value: it is not within the valid range.
INVALIDPARAMETERVALUE_OUTOFRANGE = 'InvalidParameterValue.OutOfRange'

# Invalid parametric value: the snapshot ID format is invalid.
INVALIDPARAMETERVALUE_SNAPSHOTIDMALFORMED = 'InvalidParameterValue.SnapshotIdMalformed'

# Invalid parametric value: the length of the snapshot name exceeds the upper limit.
INVALIDPARAMETERVALUE_SNAPSHOTNAMETOOLONG = 'InvalidParameterValue.SnapshotNameTooLong'

# The length of the parameter value exceeds the upper limit.
INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'

# Invalid AZ.
INVALIDPARAMETERVALUE_ZONEINVALID = 'InvalidParameterValue.ZoneInvalid'

# Reached the quota limit.
LIMITEXCEEDED = 'LimitExceeded'

# Reached the upper limit of attached data disks of the instance
LIMITEXCEEDED_ATTACHDATADISKQUOTALIMITEXCEEDED = 'LimitExceeded.AttachDataDiskQuotaLimitExceeded'

# The firewall rule quota is exceeded.
LIMITEXCEEDED_FIREWALLRULESLIMITEXCEEDED = 'LimitExceeded.FirewallRulesLimitExceeded'

# Run out of the instance quota.
LIMITEXCEEDED_INSTANCEQUOTALIMITEXCEEDED = 'LimitExceeded.InstanceQuotaLimitExceeded'

# The key pair quota is exceeded.
LIMITEXCEEDED_KEYPAIRLIMITEXCEEDED = 'LimitExceeded.KeyPairLimitExceeded'

# The snapshot quota is exceeded.
LIMITEXCEEDED_SNAPSHOTQUOTALIMITEXCEEDED = 'LimitExceeded.SnapshotQuotaLimitExceeded'

# Missing parameter.
MISSINGPARAMETER = 'MissingParameter'

# This instance does not support upgrading packages.
OPERATIONDENIED_BUNDLENOTSUPPORTMODIFY = 'OperationDenied.BundleNotSupportModify'

# The disk is being created.
OPERATIONDENIED_DISKCREATING = 'OperationDenied.DiskCreating'

# The disk is being manipulated. Try again later.
OPERATIONDENIED_DISKOPERATIONINPROGRESS = 'OperationDenied.DiskOperationInProgress'

# The cloud disk type of the disk does not support this operation.
OPERATIONDENIED_DISKUSAGENOTSUPPORTOPERATION = 'OperationDenied.DiskUsageNotSupportOperation'

# It is not allowed to manipulate this instance, as it is being created.
OPERATIONDENIED_INSTANCECREATING = 'OperationDenied.InstanceCreating'

# It is not allowed to manipulate this instance, as the last operation is still in progress.
OPERATIONDENIED_INSTANCEOPERATIONINPROGRESS = 'OperationDenied.InstanceOperationInProgress'

# Instances using storage packages do not support snapshot creation.
OPERATIONDENIED_OPERATIONDENIEDCREATESNAPSHOTFORSTORAGEBUNDLE = 'OperationDenied.OperationDeniedCreateSnapshotForStorageBundle'

# The key pair is in use.
RESOURCEINUSE_KEYPAIRINUSE = 'ResourceInUse.KeyPairInUse'

# The resource does not exist.
RESOURCENOTFOUND = 'ResourceNotFound'

# The image ID does not exist.
RESOURCENOTFOUND_BLUEPRINTIDNOTFOUND = 'ResourceNotFound.BlueprintIdNotFound'

# The specified image does not exist. Please check whether the `BlueprintId` of the image is correct.
RESOURCENOTFOUND_BLUEPRINTNOTFOUND = 'ResourceNotFound.BlueprintNotFound'

# The disk ID does not exist.
RESOURCENOTFOUND_DISKIDNOTFOUND = 'ResourceNotFound.DiskIdNotFound'

# The disk does not exist.
RESOURCENOTFOUND_DISKNOTFOUND = 'ResourceNotFound.DiskNotFound'

# The firewall does not exist.
RESOURCENOTFOUND_FIREWALLNOTFOUND = 'ResourceNotFound.FirewallNotFound'

# The firewall rule does not exist.
RESOURCENOTFOUND_FIREWALLRULESNOTFOUND = 'ResourceNotFound.FirewallRulesNotFound'

# 
RESOURCENOTFOUND_INSTANCEDATADISKNOTFOUND = 'ResourceNotFound.InstanceDataDiskNotFound'

# The instance ID does not exist.
RESOURCENOTFOUND_INSTANCEIDNOTFOUND = 'ResourceNotFound.InstanceIdNotFound'

# The instance does not exist.
RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'

# The key pair ID does not exist.
RESOURCENOTFOUND_KEYIDNOTFOUND = 'ResourceNotFound.KeyIdNotFound'

# The snapshot ID does not exist.
RESOURCENOTFOUND_SNAPSHOTIDNOTFOUND = 'ResourceNotFound.SnapshotIdNotFound'

# The snapshot does not exist.
RESOURCENOTFOUND_SNAPSHOTNOTFOUND = 'ResourceNotFound.SnapshotNotFound'

# The resource is unavailable.
RESOURCEUNAVAILABLE = 'ResourceUnavailable'

# The image resource is not available.
RESOURCEUNAVAILABLE_BLUEPRINTUNAVAILABLE = 'ResourceUnavailable.BlueprintUnavailable'

# The package is not available.
RESOURCEUNAVAILABLE_BUNDLEUNAVAILABLE = 'ResourceUnavailable.BundleUnavailable'

# There is no available configuration in the package.
RESOURCESSOLDOUT_PURCHASESOURCEHASNOBUNDLECONFIGS = 'ResourcesSoldOut.PurchaseSourceHasNoBundleConfigs'

# There is no available configuration in the package.
RESOURCESSOLDOUT_ZONESHASNOBUNDLECONFIGS = 'ResourcesSoldOut.ZonesHasNoBundleConfigs'

# MFA has expired.
UNAUTHORIZEDOPERATION_MFAEXPIRED = 'UnauthorizedOperation.MFAExpired'

# MFA does not exist.
UNAUTHORIZEDOPERATION_MFANOTFOUND = 'UnauthorizedOperation.MFANotFound'

# 
UNAUTHORIZEDOPERATION_NOPERMISSION = 'UnauthorizedOperation.NoPermission'

# Unknown parameter error.
UNKNOWNPARAMETER = 'UnknownParameter'

# Unsupported operation.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# Unable to associate with CCN: there is no instance in this region
UNSUPPORTEDOPERATION_ATTACHCCNCONDITIONUNSATISFIED = 'UnsupportedOperation.AttachCcnConditionUnsatisfied'

# Failed to associate the CCN instance. Please check the CCN status and try again later.
UNSUPPORTEDOPERATION_ATTACHCCNFAILED = 'UnsupportedOperation.AttachCcnFailed'

# The current status of the image does not support this operation.
UNSUPPORTEDOPERATION_BLUEPRINTCURSTATEINVALID = 'UnsupportedOperation.BlueprintCurStateInvalid'

# The image is in use, so this operation is not supported.
UNSUPPORTEDOPERATION_BLUEPRINTOCCUPIED = 'UnsupportedOperation.BlueprintOccupied'

# The CCN instance is already associated, and reassociation is not supported.
UNSUPPORTEDOPERATION_CCNALREADYATTACHED = 'UnsupportedOperation.CcnAlreadyAttached'

# No CCN instance has been associated yet, so this operation is not supported.
UNSUPPORTEDOPERATION_CCNNOTATTACHED = 'UnsupportedOperation.CcnNotAttached'

# Failed to query the status of the associated CCN instance. Please try again later.
UNSUPPORTEDOPERATION_DESCRIBECCNATTACHEDINSTANCESFAILED = 'UnsupportedOperation.DescribeCcnAttachedInstancesFailed'

# Failed to unassociate the CCN instance. Please check the CCN status and try again later.
UNSUPPORTEDOPERATION_DETACHCCNFAILED = 'UnsupportedOperation.DetachCcnFailed'

# The disk is busy.
UNSUPPORTEDOPERATION_DISKBUSY = 'UnsupportedOperation.DiskBusy'

# Unsupported operation: the last operation of the disk has not been completed.
UNSUPPORTEDOPERATION_DISKLATESTOPERATIONUNFINISHED = 'UnsupportedOperation.DiskLatestOperationUnfinished'

# The firewall is busy.
UNSUPPORTEDOPERATION_FIREWALLBUSY = 'UnsupportedOperation.FirewallBusy'

# The specified firewall version number does not match the current version.
UNSUPPORTEDOPERATION_FIREWALLVERSIONMISMATCH = 'UnsupportedOperation.FirewallVersionMismatch'

# Unsupported operation: the instance has expired.
UNSUPPORTEDOPERATION_INSTANCEEXPIRED = 'UnsupportedOperation.InstanceExpired'

# The password can not be set upon creation of a LinuxUnix instance.
UNSUPPORTEDOPERATION_INSTANCELINUXUNIXCREATINGNOTSUPPORTPASSWORD = 'UnsupportedOperation.InstanceLinuxUnixCreatingNotSupportPassword'

# The disk's status does not support this operation.
UNSUPPORTEDOPERATION_INVALIDDISKSTATE = 'UnsupportedOperation.InvalidDiskState'

# Unsupported operation: the instance status is invalid.
UNSUPPORTEDOPERATION_INVALIDINSTANCESTATE = 'UnsupportedOperation.InvalidInstanceState'

# Unsupported operation: the snapshot status is invalid.
UNSUPPORTEDOPERATION_INVALIDSNAPSHOTSTATE = 'UnsupportedOperation.InvalidSnapshotState'

# Unsupported operation: one key pair cannot be bound to the same instance repeatedly.
UNSUPPORTEDOPERATION_KEYPAIRBINDDUPLICATE = 'UnsupportedOperation.KeyPairBindDuplicate'

# Unsupported operation: the `KeyPair` has a binding relationship with the image. Before performing this operation, please delete the custom image bound to the key pair.
UNSUPPORTEDOPERATION_KEYPAIRBINDTOBLUEPRINTS = 'UnsupportedOperation.KeyPairBindToBlueprints'

# Unsupported operation: key pairs that are not bound to instances cannot be unbound from instances.
UNSUPPORTEDOPERATION_KEYPAIRNOTBOUNDTOINSTANCE = 'UnsupportedOperation.KeyPairNotBoundToInstance'

# Unsupported operation: the last operation of the instance has not been completed.
UNSUPPORTEDOPERATION_LATESTOPERATIONUNFINISHED = 'UnsupportedOperation.LatestOperationUnfinished'

# The shared image does not support this operation.
UNSUPPORTEDOPERATION_NOTSUPPORTSHAREDBLUEPRINT = 'UnsupportedOperation.NotSupportSharedBlueprint'

# Terminating a resource in the resource center failed.
UNSUPPORTEDOPERATION_POSTDESTROYRESOURCEFAILED = 'UnsupportedOperation.PostDestroyResourceFailed'

# Failed to reapply to associate a CCN instance. Please check the CCN status and try again later.
UNSUPPORTEDOPERATION_RESETATTACHCCNFAILED = 'UnsupportedOperation.ResetAttachCcnFailed'

# The snapshot is busy.
UNSUPPORTEDOPERATION_SNAPSHOTBUSY = 'UnsupportedOperation.SnapshotBusy'

# 
UNSUPPORTEDOPERATION_SYSTEMBUSY = 'UnsupportedOperation.SystemBusy'

# Windows instances do not support binding key pairs.
UNSUPPORTEDOPERATION_WINDOWSNOTALLOWTOASSOCIATEKEYPAIR = 'UnsupportedOperation.WindowsNotAllowToAssociateKeyPair'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Your account failed the qualification verification.
ACCOUNTQUALIFICATIONRESTRICTIONS = 'AccountQualificationRestrictions'

# Role name authentication failed.
AUTHFAILURE_CAMROLENAMEAUTHENTICATEFAILED = 'AuthFailure.CamRoleNameAuthenticateFailed'

# ENIs do not support changing subnets.
ENINOTALLOWEDCHANGESUBNET = 'EniNotAllowedChangeSubnet'

# The account already exists.
FAILEDOPERATION_ACCOUNTALREADYEXISTS = 'FailedOperation.AccountAlreadyExists'

# You cannot share images with yourself.
FAILEDOPERATION_ACCOUNTISYOURSELF = 'FailedOperation.AccountIsYourSelf'

# BYOL images cannot be shared.
FAILEDOPERATION_BYOLIMAGESHAREFAILED = 'FailedOperation.BYOLImageShareFailed'

# The specified spread placement group does not exist.
FAILEDOPERATION_DISASTERRECOVERGROUPNOTFOUND = 'FailedOperation.DisasterRecoverGroupNotFound'

# The tag key contains invalid characters.
FAILEDOPERATION_ILLEGALTAGKEY = 'FailedOperation.IllegalTagKey'

# The tag value contains invalid characters.
FAILEDOPERATION_ILLEGALTAGVALUE = 'FailedOperation.IllegalTagValue'

# Price query failed.
FAILEDOPERATION_INQUIRYPRICEFAILED = 'FailedOperation.InquiryPriceFailed'

# Failed to query the refund: the payment order is not found. Check whether the instance `ins-xxxxxxx` has expired.
FAILEDOPERATION_INQUIRYREFUNDPRICEFAILED = 'FailedOperation.InquiryRefundPriceFailed'

# The EMR instance `ins-xxxxxxxx` does not support this operation.
FAILEDOPERATION_INVALIDINSTANCEAPPLICATIONROLEEMR = 'FailedOperation.InvalidInstanceApplicationRoleEmr'

# No available IPs in the subnet.
FAILEDOPERATION_NOAVAILABLEIPADDRESSCOUNTINSUBNET = 'FailedOperation.NoAvailableIpAddressCountInSubnet'

# This instance does not bind an EIP.
FAILEDOPERATION_NOTFOUNDEIP = 'FailedOperation.NotFoundEIP'

# You’re using a collaborator account. Please enter a root account.
FAILEDOPERATION_NOTMASTERACCOUNT = 'FailedOperation.NotMasterAccount'

# The specified placement group is not empty.
FAILEDOPERATION_PLACEMENTSETNOTEMPTY = 'FailedOperation.PlacementSetNotEmpty'

# The configuration or billing mode of the CVM instances purchased during the promotion period cannot be modified.
FAILEDOPERATION_PROMOTIONALPERIORESTRICTION = 'FailedOperation.PromotionalPerioRestriction'

# The service is not available in this country/region.
FAILEDOPERATION_PROMOTIONALREGIONRESTRICTION = 'FailedOperation.PromotionalRegionRestriction'

# Image sharing failed.
FAILEDOPERATION_QIMAGESHAREFAILED = 'FailedOperation.QImageShareFailed'

# Image sharing failed.
FAILEDOPERATION_RIMAGESHAREFAILED = 'FailedOperation.RImageShareFailed'

# Security group operation failed.
FAILEDOPERATION_SECURITYGROUPACTIONFAILED = 'FailedOperation.SecurityGroupActionFailed'

# The snapshot size is larger than the disk capacity. You need a larger disk space.
FAILEDOPERATION_SNAPSHOTSIZELARGERTHANDATASIZE = 'FailedOperation.SnapshotSizeLargerThanDataSize'

# The snapshot size should be larger than the cloud disk capacity.
FAILEDOPERATION_SNAPSHOTSIZELESSTHANDATASIZE = 'FailedOperation.SnapshotSizeLessThanDataSize'

# The tag key specified in the request is reserved for the system.
FAILEDOPERATION_TAGKEYRESERVED = 'FailedOperation.TagKeyReserved'

# The instance is unreturnable.
FAILEDOPERATION_UNRETURNABLE = 'FailedOperation.Unreturnable'

# The image quota has been exceeded.
IMAGEQUOTALIMITEXCEEDED = 'ImageQuotaLimitExceeded'

# You are trying to create more instances than your remaining quota allows.
INSTANCESQUOTALIMITEXCEEDED = 'InstancesQuotaLimitExceeded'

# Internal error.
INTERNALERROR = 'InternalError'

# Internal error.
INTERNALERROR_TRADEUNKNOWNERROR = 'InternalError.TradeUnknownError'

# Internal error.
INTERNALSERVERERROR = 'InternalServerError'

# Insufficient account balance.
INVALIDACCOUNT_INSUFFICIENTBALANCE = 'InvalidAccount.InsufficientBalance'

# The account has unpaid orders.
INVALIDACCOUNT_UNPAIDORDER = 'InvalidAccount.UnpaidOrder'

# Invalid account ID.
INVALIDACCOUNTID_NOTFOUND = 'InvalidAccountId.NotFound'

# You cannot share images with yourself.
INVALIDACCOUNTIS_YOURSELF = 'InvalidAccountIs.YourSelf'

# The specified ClientToken exceeds the maximum length of 64 bytes.
INVALIDCLIENTTOKEN_TOOLONG = 'InvalidClientToken.TooLong'

# Invalid filter.
INVALIDFILTER = 'InvalidFilter'

# [`Filter`](https://intl.cloud.tencent.com/document/api/213/15753?from_cn_redirect=1#Filter)
INVALIDFILTERVALUE_LIMITEXCEEDED = 'InvalidFilterValue.LimitExceeded'

# The specified operation on this CDH instance is not support .
INVALIDHOST_NOTSUPPORTED = 'InvalidHost.NotSupported'

# Invalid [CDH](https://intl.cloud.tencent.com/document/product/416?from_cn_redirect=1) `ID`. The specified [CDH](https://intl.cloud.tencent.com/document/product/416?from_cn_redirect=1) `ID` has an invalid format. For example, `host-1122` has an invalid `ID` length.
INVALIDHOSTID_MALFORMED = 'InvalidHostId.Malformed'

# The specified HostId does not exist, or does not belong to your account.
INVALIDHOSTID_NOTFOUND = 'InvalidHostId.NotFound'

# The image is being shared.
INVALIDIMAGEID_INSHARED = 'InvalidImageId.InShared'

# Invalid image status.
INVALIDIMAGEID_INCORRECTSTATE = 'InvalidImageId.IncorrectState'

# Invalid image ID format.
INVALIDIMAGEID_MALFORMED = 'InvalidImageId.Malformed'

# The image cannot be found.
INVALIDIMAGEID_NOTFOUND = 'InvalidImageId.NotFound'

# The image size exceeds the limit.
INVALIDIMAGEID_TOOLARGE = 'InvalidImageId.TooLarge'

# The specified image name already exists.
INVALIDIMAGENAME_DUPLICATE = 'InvalidImageName.Duplicate'

# The operating system type is not supported.
INVALIDIMAGEOSTYPE_UNSUPPORTED = 'InvalidImageOsType.Unsupported'

# The operating system version is not supported.
INVALIDIMAGEOSVERSION_UNSUPPORTED = 'InvalidImageOsVersion.Unsupported'

# This instance is not supported.
INVALIDINSTANCE_NOTSUPPORTED = 'InvalidInstance.NotSupported'

# Invalid instance `ID`. The specified instance `ID` has an invalid format. For example, `ins-1122` has an invalid `ID` length.
INVALIDINSTANCEID_MALFORMED = 'InvalidInstanceId.Malformed'

# No instance found.
INVALIDINSTANCEID_NOTFOUND = 'InvalidInstanceId.NotFound'

# The specified InstanceName exceeds the maximum length of 60 bytes.
INVALIDINSTANCENAME_TOOLONG = 'InvalidInstanceName.TooLong'

# This instance does not meet the [Return Policy](https://intl.cloud.tencent.com/document/product/213/9711?from_cn_redirect=1) for prepaid instances.
INVALIDINSTANCENOTSUPPORTEDPREPAIDINSTANCE = 'InvalidInstanceNotSupportedPrepaidInstance'

# This operation cannot be performed due to the current instance status.
INVALIDINSTANCESTATE = 'InvalidInstanceState'

# The specified `InstanceType` parameter has an invalid format.
INVALIDINSTANCETYPE_MALFORMED = 'InvalidInstanceType.Malformed'

# The number of key pairs exceeds the limit.
INVALIDKEYPAIR_LIMITEXCEEDED = 'InvalidKeyPair.LimitExceeded'

# Invalid key pair ID. The specified key pair ID has an invalid format. For example, `skey-1122` has an invalid `ID` length.
INVALIDKEYPAIRID_MALFORMED = 'InvalidKeyPairId.Malformed'

# Invalid key pair ID. The specified key pair ID does not exist.
INVALIDKEYPAIRID_NOTFOUND = 'InvalidKeyPairId.NotFound'

# Key pair name already exists.
INVALIDKEYPAIRNAME_DUPLICATE = 'InvalidKeyPairName.Duplicate'

# The key name cannot be empty.
INVALIDKEYPAIRNAMEEMPTY = 'InvalidKeyPairNameEmpty'

# The key name contains invalid characters. Key names can only contain letters, numbers and underscores.
INVALIDKEYPAIRNAMEINCLUDEILLEGALCHAR = 'InvalidKeyPairNameIncludeIllegalChar'

# The key name cannot exceed 25 characters.
INVALIDKEYPAIRNAMETOOLONG = 'InvalidKeyPairNameTooLong'

# A parameter error occurred.
INVALIDPARAMETER = 'InvalidParameter'

# Up to one parameter can be specified.
INVALIDPARAMETER_ATMOSTONE = 'InvalidParameter.AtMostOne'

# RootDisk ID should not be passed to DataDiskIds.
INVALIDPARAMETER_DATADISKIDCONTAINSROOTDISK = 'InvalidParameter.DataDiskIdContainsRootDisk'

# The specified data disk does not belong to the specified instance.
INVALIDPARAMETER_DATADISKNOTBELONGSPECIFIEDINSTANCE = 'InvalidParameter.DataDiskNotBelongSpecifiedInstance'

# Only one system disk snapshot can be included.
INVALIDPARAMETER_DUPLICATESYSTEMSNAPSHOTS = 'InvalidParameter.DuplicateSystemSnapshots'

# This operation is not supported under the current status of the CVM.
INVALIDPARAMETER_HOSTIDSTATUSNOTSUPPORT = 'InvalidParameter.HostIdStatusNotSupport'

# The specified HostName is invalid.
INVALIDPARAMETER_HOSTNAMEILLEGAL = 'InvalidParameter.HostNameIllegal'

# Either `ImageIds` or `SnapshotIds` must be specified.
INVALIDPARAMETER_IMAGEIDSSNAPSHOTIDSMUSTONE = 'InvalidParameter.ImageIdsSnapshotIdsMustOne'

# This API does not support instance images.
INVALIDPARAMETER_INSTANCEIMAGENOTSUPPORT = 'InvalidParameter.InstanceImageNotSupport'

# Invalid parameter dependency.
INVALIDPARAMETER_INVALIDDEPENDENCE = 'InvalidParameter.InvalidDependence'

# Invalid VPC IP address format.
INVALIDPARAMETER_INVALIDIPFORMAT = 'InvalidParameter.InvalidIpFormat'

# `ImageIds` and `Filters` cannot be specified at the same time.
INVALIDPARAMETER_INVALIDPARAMETERCOEXISTIMAGEIDSFILTERS = 'InvalidParameter.InvalidParameterCoexistImageIdsFilters'

# Invalid URL.
INVALIDPARAMETER_INVALIDPARAMETERURLERROR = 'InvalidParameter.InvalidParameterUrlError'

# `CoreCount` and `ThreadPerCore` must be specified at the same time.
INVALIDPARAMETER_LACKCORECOUNTORTHREADPERCORE = 'InvalidParameter.LackCoreCountOrThreadPerCore'

# Local data disks cannot be used to create instance images.
INVALIDPARAMETER_LOCALDATADISKNOTSUPPORT = 'InvalidParameter.LocalDataDiskNotSupport'

# Specifying an SSH key will override the original one of the image.
INVALIDPARAMETER_PARAMETERCONFLICT = 'InvalidParameter.ParameterConflict'

# Setting login password is not supported.
INVALIDPARAMETER_PASSWORDNOTSUPPORTED = 'InvalidParameter.PasswordNotSupported'

# The specified snapshot does not exist.
INVALIDPARAMETER_SNAPSHOTNOTFOUND = 'InvalidParameter.SnapshotNotFound'

# At least one of the multiple parameters must be passed in.
INVALIDPARAMETER_SPECIFYONEPARAMETER = 'InvalidParameter.SpecifyOneParameter'

# Swap disks are not supported.
INVALIDPARAMETER_SWAPDISKNOTSUPPORT = 'InvalidParameter.SwapDiskNotSupport'

# The parameter does not contain system disk snapshot.
INVALIDPARAMETER_SYSTEMSNAPSHOTNOTFOUND = 'InvalidParameter.SystemSnapshotNotFound'

# The length of parameter exceeds the limit.
INVALIDPARAMETER_VALUETOOLARGE = 'InvalidParameter.ValueTooLarge'

# The parameter combination is invalid.
INVALIDPARAMETERCOMBINATION = 'InvalidParameterCombination'

# The two specified parameters conflict. An EIP can only be bound to the instance or the specified private IP of the specified ENI.
INVALIDPARAMETERCONFLICT = 'InvalidParameterConflict'

# Incorrect parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# The number of request parameters are not equal.
INVALIDPARAMETERVALUE_AMOUNTNOTEQUAL = 'InvalidParameterValue.AmountNotEqual'

# The shared bandwidth package ID is invalid. Please provide a standard shared bandwidth package ID in the format similar to bwp-xxxxxxxx. In this format, the letter x stands for a lowercase character or a number.
INVALIDPARAMETERVALUE_BANDWIDTHPACKAGEIDMALFORMED = 'InvalidParameterValue.BandwidthPackageIdMalformed'

# The specified bandwidth package does not exist.
INVALIDPARAMETERVALUE_BANDWIDTHPACKAGEIDNOTFOUND = 'InvalidParameterValue.BandwidthPackageIdNotFound'

# The bucket does not exist.
INVALIDPARAMETERVALUE_BUCKETNOTFOUND = 'InvalidParameterValue.BucketNotFound'

# Invalid `CamRoleName`. This parameter must contain only letters, numbers and symbols (`+`, `=`, `,`, `.`, `@`, `_`, `-`).
INVALIDPARAMETERVALUE_CAMROLENAMEMALFORMED = 'InvalidParameterValue.CamRoleNameMalformed'

# Corresponding CHC hosts not found.
INVALIDPARAMETERVALUE_CHCHOSTSNOTFOUND = 'InvalidParameterValue.ChcHostsNotFound'

# No network is configured for this CHC.
INVALIDPARAMETERVALUE_CHCNETWORKEMPTY = 'InvalidParameterValue.ChcNetworkEmpty'

# The minimum capacity of a SSD data disk is 100 GB.
INVALIDPARAMETERVALUE_CLOUDSSDDATADISKSIZETOOSMALL = 'InvalidParameterValue.CloudSsdDataDiskSizeTooSmall'

# Invalid number of cores.
INVALIDPARAMETERVALUE_CORECOUNTVALUE = 'InvalidParameterValue.CoreCountValue'

# A deployment VPC already exists.
INVALIDPARAMETERVALUE_DEPLOYVPCALREADYEXISTS = 'InvalidParameterValue.DeployVpcAlreadyExists'

# Incorrect placement group ID format.
INVALIDPARAMETERVALUE_DISASTERRECOVERGROUPIDMALFORMED = 'InvalidParameterValue.DisasterRecoverGroupIdMalformed'

# Duplicate parameter value.
INVALIDPARAMETERVALUE_DUPLICATE = 'InvalidParameterValue.Duplicate'

# Duplicate tags.
INVALIDPARAMETERVALUE_DUPLICATETAGS = 'InvalidParameterValue.DuplicateTags'

# Non-GPU instances cannot be changed to the GPU instance.
INVALIDPARAMETERVALUE_GPUINSTANCEFAMILY = 'InvalidParameterValue.GPUInstanceFamily'

# Invalid IP format
INVALIDPARAMETERVALUE_IPADDRESSMALFORMED = 'InvalidParameterValue.IPAddressMalformed'

# Invalid IPv6 address
INVALIDPARAMETERVALUE_IPV6ADDRESSMALFORMED = 'InvalidParameterValue.IPv6AddressMalformed'

# The value of HostName is invalid.
INVALIDPARAMETERVALUE_ILLEGALHOSTNAME = 'InvalidParameterValue.IllegalHostName'

# Incorrect request parameter format.
INVALIDPARAMETERVALUE_INCORRECTFORMAT = 'InvalidParameterValue.IncorrectFormat'

# The specified instance type does not exist.
INVALIDPARAMETERVALUE_INSTANCETYPENOTFOUND = 'InvalidParameterValue.InstanceTypeNotFound'

# This type of instances cannot be added to the HPC cluster.
INVALIDPARAMETERVALUE_INSTANCETYPENOTSUPPORTHPCCLUSTER = 'InvalidParameterValue.InstanceTypeNotSupportHpcCluster'

# The HPC cluster needs to be specified for the high-performance computing instance.
INVALIDPARAMETERVALUE_INSTANCETYPEREQUIREDHPCCLUSTER = 'InvalidParameterValue.InstanceTypeRequiredHpcCluster'

# The spot instances are out of stock.
INVALIDPARAMETERVALUE_INSUFFICIENTOFFERING = 'InvalidParameterValue.InsufficientOffering'

# The bid is lower than the market price.
INVALIDPARAMETERVALUE_INSUFFICIENTPRICE = 'InvalidParameterValue.InsufficientPrice'

# Invalid AppID
INVALIDPARAMETERVALUE_INVALIDAPPIDFORMAT = 'InvalidParameterValue.InvalidAppIdFormat'

# You don’t have the write permission to the bucket.
INVALIDPARAMETERVALUE_INVALIDBUCKETPERMISSIONFOREXPORT = 'InvalidParameterValue.InvalidBucketPermissionForExport'

# The length of `FileNamePrefixList` does not match `ImageIds` or `SnapshotIds`.
INVALIDPARAMETERVALUE_INVALIDFILENAMEPREFIXLIST = 'InvalidParameterValue.InvalidFileNamePrefixList'

# Converting to a non-GPU or other type of GPU instance is not supported.
INVALIDPARAMETERVALUE_INVALIDGPUFAMILYCHANGE = 'InvalidParameterValue.InvalidGPUFamilyChange'

# The specified image does not support the specified instance type.
INVALIDPARAMETERVALUE_INVALIDIMAGEFORGIVENINSTANCETYPE = 'InvalidParameterValue.InvalidImageForGivenInstanceType'

# A RAW image cannot be used to create a CVM. Choose another image.
INVALIDPARAMETERVALUE_INVALIDIMAGEFORMAT = 'InvalidParameterValue.InvalidImageFormat'

# The image does not support this operation.
INVALIDPARAMETERVALUE_INVALIDIMAGEID = 'InvalidParameterValue.InvalidImageId'

# The image cannot be used to reinstall the current instance.
INVALIDPARAMETERVALUE_INVALIDIMAGEIDFORRETSETINSTANCE = 'InvalidParameterValue.InvalidImageIdForRetsetInstance'

# The operating system of the specified image is not available in the current region.
INVALIDPARAMETERVALUE_INVALIDIMAGEOSNAME = 'InvalidParameterValue.InvalidImageOsName'

# The image has another ongoing task. Please check and try again later.
INVALIDPARAMETERVALUE_INVALIDIMAGESTATE = 'InvalidParameterValue.InvalidImageState'

# The instance configuration is upgraded for free and cannot be downgraded within 3 months.
INVALIDPARAMETERVALUE_INVALIDINSTANCESOURCE = 'InvalidParameterValue.InvalidInstanceSource'

# Invalid IP address.
INVALIDPARAMETERVALUE_INVALIDIPFORMAT = 'InvalidParameterValue.InvalidIpFormat'

# Incorrect format of instance launch template name.
INVALIDPARAMETERVALUE_INVALIDLAUNCHTEMPLATENAME = 'InvalidParameterValue.InvalidLaunchTemplateName'

# Incorrect format of instance launch template version description.
INVALIDPARAMETERVALUE_INVALIDLAUNCHTEMPLATEVERSIONDESCRIPTION = 'InvalidParameterValue.InvalidLaunchTemplateVersionDescription'

# Invalid license type.
INVALIDPARAMETERVALUE_INVALIDLICENSETYPE = 'InvalidParameterValue.InvalidLicenseType'

# Invalid parameter value.
INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValue.InvalidParameterValueLimit'

# Invalid password. The specified password does not meet the complexity requirements (e.g., too long or too short)
INVALIDPARAMETERVALUE_INVALIDPASSWORD = 'InvalidParameterValue.InvalidPassword'

# The Region ID is unavailable.
INVALIDPARAMETERVALUE_INVALIDREGION = 'InvalidParameterValue.InvalidRegion'

# Incorrect time format.
INVALIDPARAMETERVALUE_INVALIDTIMEFORMAT = 'InvalidParameterValue.InvalidTimeFormat'

# Incorrect UserData format. Use the Base64-encoded format.
INVALIDPARAMETERVALUE_INVALIDUSERDATAFORMAT = 'InvalidParameterValue.InvalidUserDataFormat'

# Invalid fuzzy query string
INVALIDPARAMETERVALUE_INVALIDVAGUENAME = 'InvalidParameterValue.InvalidVagueName'

# The key does not exist.
INVALIDPARAMETERVALUE_KEYPAIRNOTFOUND = 'InvalidParameterValue.KeyPairNotFound'

# The specified key does not support the operation.
INVALIDPARAMETERVALUE_KEYPAIRNOTSUPPORTED = 'InvalidParameterValue.KeyPairNotSupported'

# The default launch template version cannot be operated.
INVALIDPARAMETERVALUE_LAUNCHTEMPLATEDEFAULTVERSION = 'InvalidParameterValue.LaunchTemplateDefaultVersion'

# Incorrect format of instance launch template ID.
INVALIDPARAMETERVALUE_LAUNCHTEMPLATEIDMALFORMED = 'InvalidParameterValue.LaunchTemplateIdMalformed'

# The instance launch template ID does not exist.
INVALIDPARAMETERVALUE_LAUNCHTEMPLATEIDNOTEXISTED = 'InvalidParameterValue.LaunchTemplateIdNotExisted'

# The combination of the template and the version ID does not exist.
INVALIDPARAMETERVALUE_LAUNCHTEMPLATEIDVERNOTEXISTED = 'InvalidParameterValue.LaunchTemplateIdVerNotExisted'

# The specified instance launch template ID doesn't exist.
INVALIDPARAMETERVALUE_LAUNCHTEMPLATEIDVERSETALREADY = 'InvalidParameterValue.LaunchTemplateIdVerSetAlready'

# The instance launch template is not found.
INVALIDPARAMETERVALUE_LAUNCHTEMPLATENOTFOUND = 'InvalidParameterValue.LaunchTemplateNotFound'

# Invalid instance launch template version number.
INVALIDPARAMETERVALUE_LAUNCHTEMPLATEVERSION = 'InvalidParameterValue.LaunchTemplateVersion'

# The number of parameter values exceeds the limit.
INVALIDPARAMETERVALUE_LIMITEXCEEDED = 'InvalidParameterValue.LimitExceeded'

# The parameter value must be a DHCP-enabled VPC.
INVALIDPARAMETERVALUE_MUSTDHCPENABLEDVPC = 'InvalidParameterValue.MustDhcpEnabledVpc'

# The subnet is not in the CDC cluster.
INVALIDPARAMETERVALUE_NOTCDCSUBNET = 'InvalidParameterValue.NotCdcSubnet'

# Unsupported operation.
INVALIDPARAMETERVALUE_NOTSUPPORTED = 'InvalidParameterValue.NotSupported'

#  Invalid parameter value: invalid parameter value range.
INVALIDPARAMETERVALUE_RANGE = 'InvalidParameterValue.Range'

# Invalid snapshot ID. Provide a snapshot ID in the format of snap-xxxxxxxx, where the letter x refers to lowercase letter or number.
INVALIDPARAMETERVALUE_SNAPSHOTIDMALFORMED = 'InvalidParameterValue.SnapshotIdMalformed'

# Invalid subnet ID. Please provide a subnet ID in the format of subnet-xxxxxxxx, where “x” can be a lowercase letter or number.
INVALIDPARAMETERVALUE_SUBNETIDMALFORMED = 'InvalidParameterValue.SubnetIdMalformed'

# Creation failed: the subnet does not exist. Please specify another subnet.
INVALIDPARAMETERVALUE_SUBNETNOTEXIST = 'InvalidParameterValue.SubnetNotExist'

# The specified tag does not exist
INVALIDPARAMETERVALUE_TAGKEYNOTFOUND = 'InvalidParameterValue.TagKeyNotFound'

# Tag quota limit exceeded.
INVALIDPARAMETERVALUE_TAGQUOTALIMITEXCEEDED = 'InvalidParameterValue.TagQuotaLimitExceeded'

# Invalid thread count per core.
INVALIDPARAMETERVALUE_THREADPERCOREVALUE = 'InvalidParameterValue.ThreadPerCoreValue'

# The parameter value exceeds the maximum limit.
INVALIDPARAMETERVALUE_TOOLARGE = 'InvalidParameterValue.TooLarge'

# Invalid parameter value: parameter value is too long.
INVALIDPARAMETERVALUE_TOOLONG = 'InvalidParameterValue.TooLong'

# The VPC ID `xxx` is invalid. Please provide a VPC ID in the format of vpc-xxxxxxxx, where “x” can be a lowercase letter or number.
INVALIDPARAMETERVALUE_VPCIDMALFORMED = 'InvalidParameterValue.VpcIdMalformed'

# The specified VpcId doesn't exist.
INVALIDPARAMETERVALUE_VPCIDNOTEXIST = 'InvalidParameterValue.VpcIdNotExist'

# The VPC and instance must be in the same availability zone.
INVALIDPARAMETERVALUE_VPCIDZONEIDNOTMATCH = 'InvalidParameterValue.VpcIdZoneIdNotMatch'

# This VPC does not support the IPv6 addresses.
INVALIDPARAMETERVALUE_VPCNOTSUPPORTIPV6ADDRESS = 'InvalidParameterValue.VpcNotSupportIpv6Address'

# The availability zone does not support this operation.
INVALIDPARAMETERVALUE_ZONENOTSUPPORTED = 'InvalidParameterValue.ZoneNotSupported'

# The number of parameter values exceeds the limit.
INVALIDPARAMETERVALUELIMIT = 'InvalidParameterValueLimit'

# Invalid parameter value: invalid `Offset`.
INVALIDPARAMETERVALUEOFFSET = 'InvalidParameterValueOffset'

# Invalid password. The specified password does not meet the password requirements. For example, the password length does not meet the requirements.
INVALIDPASSWORD = 'InvalidPassword'

# Invalid period. Valid values: [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 24, 36]; unit: month.
INVALIDPERIOD = 'InvalidPeriod'

# This operation is not supported for the account.
INVALIDPERMISSION = 'InvalidPermission'

# Invalid project ID: the specified project ID does not exist.
INVALIDPROJECTID_NOTFOUND = 'InvalidProjectId.NotFound'

# Invalid public key: the specified key already exists.
INVALIDPUBLICKEY_DUPLICATE = 'InvalidPublicKey.Duplicate'

# Invalid public key: the specified public key does not meet the `OpenSSH RSA` format requirements.
INVALIDPUBLICKEY_MALFORMED = 'InvalidPublicKey.Malformed'

# The region cannot be found.
INVALIDREGION_NOTFOUND = 'InvalidRegion.NotFound'

# Currently this region does not support image synchronization.
INVALIDREGION_UNAVAILABLE = 'InvalidRegion.Unavailable'

# The specified `security group ID` does not exist.
INVALIDSECURITYGROUPID_NOTFOUND = 'InvalidSecurityGroupId.NotFound'

# The specified `security group ID` is in the wrong format. For example, `sg-ide32` has an invalid `instance ID` length.
INVALIDSGID_MALFORMED = 'InvalidSgId.Malformed'

# The specified `zone` does not exist.
INVALIDZONE_MISMATCHREGION = 'InvalidZone.MismatchRegion'

# An instance can be bound with up to 5 security groups.
LIMITEXCEEDED_ASSOCIATEUSGLIMITEXCEEDED = 'LimitExceeded.AssociateUSGLimitExceeded'

# The CVM ENIs associated with the security group has exceeded the limit.
LIMITEXCEEDED_CVMSVIFSPERSECGROUPLIMITEXCEEDED = 'LimitExceeded.CvmsVifsPerSecGroupLimitExceeded'

# The quota of the specified placement group is insufficient.
LIMITEXCEEDED_DISASTERRECOVERGROUP = 'LimitExceeded.DisasterRecoverGroup'

# The number of EIPs of an ENI contained in a specific instance has exceeded the maximum allowed EIPs of the target instance type. Please delete some EIPs and try again.
LIMITEXCEEDED_EIPNUMLIMIT = 'LimitExceeded.EipNumLimit'

# The number of ENIs on a specified instance exceeds the maximum ENIs allowed for the target instance type. Delete some ENIs and try again.
LIMITEXCEEDED_ENINUMLIMIT = 'LimitExceeded.EniNumLimit'

# The number of image export tasks in progress reached the upper limit. Please try again after the running tasks are completed.
LIMITEXCEEDED_EXPORTIMAGETASKLIMITEXCEEDED = 'LimitExceeded.ExportImageTaskLimitExceeded'

# Number of IPs on this ENI reached the upper limit.
LIMITEXCEEDED_IPV6ADDRESSNUM = 'LimitExceeded.IPv6AddressNum'

# Reached the upper limit of the ENIs for the instance.
LIMITEXCEEDED_INSTANCEENINUMLIMIT = 'LimitExceeded.InstanceEniNumLimit'

# You are short of the instance quota.
LIMITEXCEEDED_INSTANCEQUOTA = 'LimitExceeded.InstanceQuota'

# Unable to adjust: the target instance type does not support the configured public network bandwidth cap. See [Public Network Bandwidth Cap](https://intl.cloud.tencent.com/document/product/213/12523).
LIMITEXCEEDED_INSTANCETYPEBANDWIDTH = 'LimitExceeded.InstanceTypeBandwidth'

# The number of instance launch templates exceeds the limit.
LIMITEXCEEDED_LAUNCHTEMPLATEQUOTA = 'LimitExceeded.LaunchTemplateQuota'

# The number of instance launch template versions exceeds the limit.
LIMITEXCEEDED_LAUNCHTEMPLATEVERSIONQUOTA = 'LimitExceeded.LaunchTemplateVersionQuota'

# Your quota for monthly-subscribed instances is used up. Increase your quota and try again.
LIMITEXCEEDED_PREPAYQUOTA = 'LimitExceeded.PrepayQuota'

# The number of security groups exceeds the quota limit.
LIMITEXCEEDED_SINGLEUSGQUOTA = 'LimitExceeded.SingleUSGQuota'

# The spot instance offerings are out of stock.
LIMITEXCEEDED_SPOTQUOTA = 'LimitExceeded.SpotQuota'

# Exceeded the upper limit of resources bound to the tag.
LIMITEXCEEDED_TAGRESOURCEQUOTA = 'LimitExceeded.TagResourceQuota'

# Failed to return instances because of the quota limit.
LIMITEXCEEDED_USERRETURNQUOTA = 'LimitExceeded.UserReturnQuota'

# You are short of the spot instance quota.
LIMITEXCEEDED_USERSPOTQUOTA = 'LimitExceeded.UserSpotQuota'

# Insufficient subnet IPs.
LIMITEXCEEDED_VPCSUBNETNUM = 'LimitExceeded.VpcSubnetNum'

# Missing parameter.
MISSINGPARAMETER = 'MissingParameter'

# Parameter missing. Provide at least one parameter.
MISSINGPARAMETER_ATLEASTONE = 'MissingParameter.AtLeastOne'

# The DPDK instance requires a VPC.
MISSINGPARAMETER_DPDKINSTANCETYPEREQUIREDVPC = 'MissingParameter.DPDKInstanceTypeRequiredVPC'

# The instance type must have Cloud Monitor enabled.
MISSINGPARAMETER_MONITORSERVICE = 'MissingParameter.MonitorService'

# An identical job is running.
MUTEXOPERATION_TASKRUNNING = 'MutexOperation.TaskRunning'

# A CHC instance without network configured is not allowed for the installation of a cloud image
OPERATIONDENIED_CHCINSTALLCLOUDIMAGEWITHOUTDEPLOYNETWORK = 'OperationDenied.ChcInstallCloudImageWithoutDeployNetwork'

# Operation denied: This is a restricted account.
OPERATIONDENIED_INNERUSERPROHIBITACTION = 'OperationDenied.InnerUserProhibitAction'

# The instance has an operation in progress. Please try again later.
OPERATIONDENIED_INSTANCEOPERATIONINPROGRESS = 'OperationDenied.InstanceOperationInProgress'

# The number of shared images exceeds the quota.
OVERQUOTA = 'OverQuota'

# This region does not support importing images.
REGIONABILITYLIMIT_UNSUPPORTEDTOIMPORTIMAGE = 'RegionAbilityLimit.UnsupportedToImportImage'

# The resource is in use.
RESOURCEINUSE = 'ResourceInUse'

# The availability zone has been sold out.
RESOURCEINSUFFICIENT_AVAILABILITYZONESOLDOUT = 'ResourceInsufficient.AvailabilityZoneSoldOut'

# The specified cloud disk has been sold out.
RESOURCEINSUFFICIENT_CLOUDDISKSOLDOUT = 'ResourceInsufficient.CloudDiskSoldOut'

# The parameters of cloud disk do not meet the specification.
RESOURCEINSUFFICIENT_CLOUDDISKUNAVAILABLE = 'ResourceInsufficient.CloudDiskUnavailable'

# The number of instances exceeded the quota limit of spread placement groups.
RESOURCEINSUFFICIENT_DISASTERRECOVERGROUPCVMQUOTA = 'ResourceInsufficient.DisasterRecoverGroupCvmQuota'

# The specified instance type is insufficient.
RESOURCEINSUFFICIENT_SPECIFIEDINSTANCETYPE = 'ResourceInsufficient.SpecifiedInstanceType'

# The instances of the specified types were sold out in the selected AZs.
RESOURCEINSUFFICIENT_ZONESOLDOUTFORSPECIFIEDINSTANCE = 'ResourceInsufficient.ZoneSoldOutForSpecifiedInstance'

# The HPC cluster does not exist.
RESOURCENOTFOUND_HPCCLUSTER = 'ResourceNotFound.HpcCluster'

# The specified placement group does not exist.
RESOURCENOTFOUND_INVALIDPLACEMENTSET = 'ResourceNotFound.InvalidPlacementSet'

# This instance type is not supported in the AZ.
RESOURCENOTFOUND_INVALIDZONEINSTANCETYPE = 'ResourceNotFound.InvalidZoneInstanceType'

# No default CBS resources are available.
RESOURCENOTFOUND_NODEFAULTCBS = 'ResourceNotFound.NoDefaultCbs'

# No default CBS resources are available.
RESOURCENOTFOUND_NODEFAULTCBSWITHREASON = 'ResourceNotFound.NoDefaultCbsWithReason'

# This instance type is unavailable in the availability zone.
RESOURCEUNAVAILABLE_INSTANCETYPE = 'ResourceUnavailable.InstanceType'

# The snapshot is being created.
RESOURCEUNAVAILABLE_SNAPSHOTCREATING = 'ResourceUnavailable.SnapshotCreating'

# Resources in this availability zone has been sold out.
RESOURCESSOLDOUT_AVAILABLEZONE = 'ResourcesSoldOut.AvailableZone'

# The public IP has been sold out.
RESOURCESSOLDOUT_EIPINSUFFICIENT = 'ResourcesSoldOut.EipInsufficient'

# The specified instance type is sold out.
RESOURCESSOLDOUT_SPECIFIEDINSTANCETYPE = 'ResourcesSoldOut.SpecifiedInstanceType'

# A general error occurred during the security group service API call.
SECGROUPACTIONFAILURE = 'SecGroupActionFailure'

# 
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# The specified image does not belong to the user.
UNAUTHORIZEDOPERATION_IMAGENOTBELONGTOACCOUNT = 'UnauthorizedOperation.ImageNotBelongToAccount'

# Check if the token is valid.
UNAUTHORIZEDOPERATION_INVALIDTOKEN = 'UnauthorizedOperation.InvalidToken'

# Unauthorized operation. Make sure Multi-Factor Authentication (MFA) is valid.
UNAUTHORIZEDOPERATION_MFAEXPIRED = 'UnauthorizedOperation.MFAExpired'

# Unauthorized operation. Make sure Multi-Factor Authentication (MFA) exists.
UNAUTHORIZEDOPERATION_MFANOTFOUND = 'UnauthorizedOperation.MFANotFound'

# You’re not authorized for the operation. Please check the CAM policy.
UNAUTHORIZEDOPERATION_PERMISSIONDENIED = 'UnauthorizedOperation.PermissionDenied'

# Unknown parameter error.
UNKNOWNPARAMETER = 'UnknownParameter'

# Unsupported operation.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# The specified instance or network cannot use the bandwidth package.
UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.BandwidthPackageIdNotSupported'

# You cannot change the model of a heterogeneous instance.
UNSUPPORTEDOPERATION_HETEROGENEOUSCHANGEINSTANCEFAMILY = 'UnsupportedOperation.HeterogeneousChangeInstanceFamily'

# IPv6 instances cannot be migrated from Classiclink to VPC.
UNSUPPORTEDOPERATION_IPV6NOTSUPPORTVPCMIGRATE = 'UnsupportedOperation.IPv6NotSupportVpcMigrate'

# Failed to export the image: The image is too large.
UNSUPPORTEDOPERATION_IMAGETOOLARGEEXPORTUNSUPPORTED = 'UnsupportedOperation.ImageTooLargeExportUnsupported'

# This instance billing mode does not support the operation.
UNSUPPORTEDOPERATION_INSTANCECHARGETYPE = 'UnsupportedOperation.InstanceChargeType'

# A mixed payment mode is not supported.
UNSUPPORTEDOPERATION_INSTANCEMIXEDPRICINGMODEL = 'UnsupportedOperation.InstanceMixedPricingModel'

# The instance `ins-xxxxxx` with the `Xserver windows2012cndatacenterx86_64` operating system does not support this operation.
UNSUPPORTEDOPERATION_INSTANCEOSWINDOWS = 'UnsupportedOperation.InstanceOsWindows'

# This CVM is blocked. Please submit a ticket.
UNSUPPORTEDOPERATION_INSTANCESTATEBANNING = 'UnsupportedOperation.InstanceStateBanning'

# The instances are permanently corrupted, and this operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATECORRUPTED = 'UnsupportedOperation.InstanceStateCorrupted'

# Instances are entering the rescue mode, and this operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATEENTERRESCUEMODE = 'UnsupportedOperation.InstanceStateEnterRescueMode'

# The instance `ins-xxxxxx` in the `ENTER_SERVICE_LIVE_MIGRATE` status is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATEENTERSERVICELIVEMIGRATE = 'UnsupportedOperation.InstanceStateEnterServiceLiveMigrate'

# Instances are exiting from the rescue mode, and this operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATEEXITRESCUEMODE = 'UnsupportedOperation.InstanceStateExitRescueMode'

# The instance `ins-xxxxxx` in the `EXIT_SERVICE_LIVE_MIGRATE` status is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATEEXITSERVICELIVEMIGRATE = 'UnsupportedOperation.InstanceStateExitServiceLiveMigrate'

# The operation is not supported for the frozen instances.
UNSUPPORTEDOPERATION_INSTANCESTATEFREEZING = 'UnsupportedOperation.InstanceStateFreezing'

# Unable to isolate: the instance is isolated
UNSUPPORTEDOPERATION_INSTANCESTATEISOLATING = 'UnsupportedOperation.InstanceStateIsolating'

# The instances are being created, and this operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATEPENDING = 'UnsupportedOperation.InstanceStatePending'

# The instances are being restarted, and this operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATEREBOOTING = 'UnsupportedOperation.InstanceStateRebooting'

# Instances in the rescue mode are not available for this operation.
UNSUPPORTEDOPERATION_INSTANCESTATERESCUEMODE = 'UnsupportedOperation.InstanceStateRescueMode'

# Running instances do not support this operation.
UNSUPPORTEDOPERATION_INSTANCESTATERUNNING = 'UnsupportedOperation.InstanceStateRunning'

# The instances are being migrated, and this operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATESERVICELIVEMIGRATE = 'UnsupportedOperation.InstanceStateServiceLiveMigrate'

# Isolated instances do not support this operation.
UNSUPPORTEDOPERATION_INSTANCESTATESHUTDOWN = 'UnsupportedOperation.InstanceStateShutdown'

# The instance is starting up, and this operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATESTARTING = 'UnsupportedOperation.InstanceStateStarting'

# The instance has been shut down, and this operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATESTOPPED = 'UnsupportedOperation.InstanceStateStopped'

# The instance is being shut down, and this operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATESTOPPING = 'UnsupportedOperation.InstanceStateStopping'

# Terminated instances are not supported.
UNSUPPORTEDOPERATION_INSTANCESTATETERMINATED = 'UnsupportedOperation.InstanceStateTerminated'

# The instance is being terminated, and the operation is not supported.
UNSUPPORTEDOPERATION_INSTANCESTATETERMINATING = 'UnsupportedOperation.InstanceStateTerminating'

# The instance is under termination protection and cannot be terminated. Disable the termination protection and try again.
UNSUPPORTEDOPERATION_INSTANCESPROTECTED = 'UnsupportedOperation.InstancesProtected'

# Adjusting the data disk is not supported.
UNSUPPORTEDOPERATION_INVALIDDATADISK = 'UnsupportedOperation.InvalidDataDisk'

# The specified disk is not supported.
UNSUPPORTEDOPERATION_INVALIDDISK = 'UnsupportedOperation.InvalidDisk'

# The image license type does not match the instance. Select another image.
UNSUPPORTEDOPERATION_INVALIDIMAGELICENSETYPEFORRESET = 'UnsupportedOperation.InvalidImageLicenseTypeForReset'

# This operation is not supported for the instance with a termination schedule. Please cancel the scheduled termination time in the instance details page and try again.
UNSUPPORTEDOPERATION_INVALIDINSTANCENOTSUPPORTEDPROTECTEDINSTANCE = 'UnsupportedOperation.InvalidInstanceNotSupportedProtectedInstance'

# The current operation is only supported for Tencent Cloud International users.
UNSUPPORTEDOPERATION_INVALIDPERMISSIONNONINTERNATIONALACCOUNT = 'UnsupportedOperation.InvalidPermissionNonInternationalAccount'

# Encrypted disks are not available in the selected regions.
UNSUPPORTEDOPERATION_INVALIDREGIONDISKENCRYPT = 'UnsupportedOperation.InvalidRegionDiskEncrypt'

# Key-pair login is not available to Windows instances.
UNSUPPORTEDOPERATION_KEYPAIRUNSUPPORTEDWINDOWS = 'UnsupportedOperation.KeyPairUnsupportedWindows'

# A model whose data disks are all local disks does not support cross-model configuration adjustment.
UNSUPPORTEDOPERATION_LOCALDATADISKCHANGEINSTANCEFAMILY = 'UnsupportedOperation.LocalDataDiskChangeInstanceFamily'

# The specified disk is converting to a cloud disk. Try again later.
UNSUPPORTEDOPERATION_LOCALDISKMIGRATINGTOCLOUDDISK = 'UnsupportedOperation.LocalDiskMigratingToCloudDisk'

# The custom images created with the market images cannot be exported.
UNSUPPORTEDOPERATION_MARKETIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.MarketImageExportUnsupported'

# An instance bound with CLB does not support modifying its VPC attributes.
UNSUPPORTEDOPERATION_MODIFYVPCWITHCLB = 'UnsupportedOperation.ModifyVPCWithCLB'

# This instance type does not support spot instances.
UNSUPPORTEDOPERATION_NOINSTANCETYPESUPPORTSPOT = 'UnsupportedOperation.NoInstanceTypeSupportSpot'

# 
UNSUPPORTEDOPERATION_NOVPCNETWORK = 'UnsupportedOperation.NoVpcNetwork'

# Failed to configure the scheduled action for the current instance. 
UNSUPPORTEDOPERATION_NOTSUPPORTIMPORTINSTANCESACTIONTIMER = 'UnsupportedOperation.NotSupportImportInstancesActionTimer'

# The instance does not support this operation.
UNSUPPORTEDOPERATION_NOTSUPPORTINSTANCEIMAGE = 'UnsupportedOperation.NotSupportInstanceImage'

# Only a prepaid account supports this operation.
UNSUPPORTEDOPERATION_ONLYFORPREPAIDACCOUNT = 'UnsupportedOperation.OnlyForPrepaidAccount'

# The original instance type is invalid.
UNSUPPORTEDOPERATION_ORIGINALINSTANCETYPEINVALID = 'UnsupportedOperation.OriginalInstanceTypeInvalid'

# Public images and market images cannot be exported.
UNSUPPORTEDOPERATION_PUBLICIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.PublicImageExportUnsupported'

# This image does not support instance reinstallation.
UNSUPPORTEDOPERATION_RAWLOCALDISKINSREINSTALLTOQCOW2 = 'UnsupportedOperation.RawLocalDiskInsReinstalltoQcow2'

# The region is unsupported.
UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'

# Purchasing reserved instances is not supported for the current user.
UNSUPPORTEDOPERATION_RESERVEDINSTANCEINVISIBLEFORUSER = 'UnsupportedOperation.ReservedInstanceInvisibleForUser'

# You’ve used up your quota for Reserved Instances.
UNSUPPORTEDOPERATION_RESERVEDINSTANCEOUTOFQUATA = 'UnsupportedOperation.ReservedInstanceOutofQuata'

# Shared images cannot be exported.
UNSUPPORTEDOPERATION_SHAREDIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.SharedImageExportUnsupported'

# This special instance type does not support the operation.
UNSUPPORTEDOPERATION_SPECIALINSTANCETYPE = 'UnsupportedOperation.SpecialInstanceType'

# 
UNSUPPORTEDOPERATION_SPOTUNSUPPORTEDREGION = 'UnsupportedOperation.SpotUnsupportedRegion'

# The instance does not support the **no charges when shut down** feature.
UNSUPPORTEDOPERATION_STOPPEDMODESTOPCHARGING = 'UnsupportedOperation.StoppedModeStopCharging'

# Configuration adjustment of the same type is not supported for instances with no charges when shut down.
UNSUPPORTEDOPERATION_STOPPEDMODESTOPCHARGINGSAMEFAMILY = 'UnsupportedOperation.StoppedModeStopChargingSameFamily'

# The specified model does not support cross-model configuration adjustment.
UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCEFAMILY = 'UnsupportedOperation.UnsupportedChangeInstanceFamily'

# Non-ARM model instances cannot be changed to the ARM model.
UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCEFAMILYTOARM = 'UnsupportedOperation.UnsupportedChangeInstanceFamilyToARM'

# The target model (SA3) does not support configuration adjustment.
UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCEFAMILYTOSA3 = 'UnsupportedOperation.UnsupportedChangeInstanceFamilyToSA3'

# Changing to this model type for this instance is not allowed.
UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCETOTHISINSTANCEFAMILY = 'UnsupportedOperation.UnsupportedChangeInstanceToThisInstanceFamily'

# This operation is not available for Tencent Cloud International users.
UNSUPPORTEDOPERATION_UNSUPPORTEDINTERNATIONALUSER = 'UnsupportedOperation.UnsupportedInternationalUser'

# The quota of user limit operations is insufficient.
UNSUPPORTEDOPERATION_USERLIMITOPERATIONEXCEEDQUOTA = 'UnsupportedOperation.UserLimitOperationExceedQuota'

# Windows images cannot be exported.
UNSUPPORTEDOPERATION_WINDOWSIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.WindowsImageExportUnsupported'

# The VPC IP address is not in the subnet.
VPCADDRNOTINSUBNET = 'VpcAddrNotInSubNet'

# The VPC IP address is already occupied.
VPCIPISUSED = 'VpcIpIsUsed'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Authentication error. Please check and try again.
AUTHFAILURE_INVALIDAUTHORIZATION = 'AuthFailure.InvalidAuthorization'

# Failed to update the domain name configuration. Please submit a ticket for troubleshooting.
FAILEDOPERATION_CDNCONFIGERROR = 'FailedOperation.CdnConfigError'

# Authentication system internal error.
INTERNALERROR_CAMSYSTEMERROR = 'InternalError.CamSystemError'

# Failed to update the domain name configuration.
INTERNALERROR_CDNCONFIGERROR = 'InternalError.CdnConfigError'

# Internal data error. Please submit a ticket for troubleshooting.
INTERNALERROR_CDNDBERROR = 'InternalError.CdnDbError'

# Internal error. Please try again or contact the customer service for assistance.
INTERNALERROR_CDNQUERYPARAMERROR = 'InternalError.CdnQueryParamError'

# Internal error. Please try again or contact the customer service for assistance.
INTERNALERROR_CDNQUERYSYSTEMERROR = 'InternalError.CdnQuerySystemError'

# System error. Please submit a ticket for troubleshooting.
INTERNALERROR_CDNSYSTEMERROR = 'InternalError.CdnSystemError'

# CLS internal error.
INTERNALERROR_CLSINTERNALERROR = 'InternalError.ClsInternalError'

# Billing data query internal error. Please submit a ticket for troubleshooting.
INTERNALERROR_COSTDATASYSTEMERROR = 'InternalError.CostDataSystemError'

# Error with the data query. Please submit a ticket for troubleshooting.
INTERNALERROR_DATASYSTEMERROR = 'InternalError.DataSystemError'

# Service internal error. Please submit a ticket for troubleshooting.
INTERNALERROR_ERROR = 'InternalError.Error'

# Service internal error. Please submit a ticket for troubleshooting.
INTERNALERROR_INVALIDERRORCODE = 'InternalError.InvalidErrorCode'

# Internal service error. Please submit a ticket for troubleshooting.
INTERNALERROR_PROXYSERVER = 'InternalError.ProxyServer'

# Internal service error. Please submit a ticket for troubleshooting.
INTERNALERROR_ROUTEERROR = 'InternalError.RouteError'

# The SCDN service is not activated. Please purchase or renew an SCDN packet and try again.
INTERNALERROR_SCDNUSERNOPACKAGE = 'InternalError.ScdnUserNoPackage'

# Your SCDN service is suspended. Please purchase a new SCDN packet.
INTERNALERROR_SCDNUSERSUSPEND = 'InternalError.ScdnUserSuspend'

# Tag internal error. Please submit a ticket for troubleshooting.
INTERNALERROR_TAGSYSTEMERROR = 'InternalError.TagSystemError'

# The access port 443 must be enabled for HTTPS configuration.
INVALIDPARAMETER_ACCESSPORTOPENEDHTTPS = 'InvalidParameter.AccessPortOpenedHttps'

# Please delete the rate limiting configuration before you switch the acceleration region.
INVALIDPARAMETER_BANDLIMITREQUIREDMAINLAND = 'InvalidParameter.BandLimitRequiredMainland'

# Tencent Cloud COS and third-party object storage origins only support "Return 404". Please modify and try again.
INVALIDPARAMETER_BANDWIDTHALERTCOUNTERMEASURECONFLICTORIGINTYPE = 'InvalidParameter.BandwidthAlertCounterMeasureConflictOriginType'

# Invalid domain name status.
INVALIDPARAMETER_CDNSTATUSINVALIDDOMAIN = 'InvalidParameter.CDNStatusInvalidDomain'

# The certificate information is invalid or does not exist. Please check and try again.
INVALIDPARAMETER_CDNCERTINFONOTFOUND = 'InvalidParameter.CdnCertInfoNotFound'

# Invalid certificate. Please check and try again.
INVALIDPARAMETER_CDNCERTNOCERTINFO = 'InvalidParameter.CdnCertNoCertInfo'

# Invalid HTTPS certificate.
INVALIDPARAMETER_CDNCERTNOTPEM = 'InvalidParameter.CdnCertNotPem'

# A duplicate topic is found.
INVALIDPARAMETER_CDNCLSDUPLICATETOPIC = 'InvalidParameter.CdnClsDuplicateTopic'

# Invalid topic name.
INVALIDPARAMETER_CDNCLSTOPICNAMEINVALID = 'InvalidParameter.CdnClsTopicNameInvalid'

# The CLS topic does not exist.
INVALIDPARAMETER_CDNCLSTOPICNOTEXIST = 'InvalidParameter.CdnClsTopicNotExist'

# Invalid cache configuration. Please check and try again.
INVALIDPARAMETER_CDNCONFIGINVALIDCACHE = 'InvalidParameter.CdnConfigInvalidCache'

# Invalid domain name. Please make sure the domain name is valid.
INVALIDPARAMETER_CDNCONFIGINVALIDHOST = 'InvalidParameter.CdnConfigInvalidHost'

# The domain name is configured with special configurations, please submit a ticket.
INVALIDPARAMETER_CDNHOSTHASSPECIALCONFIG = 'InvalidParameter.CdnHostHasSpecialConfig'

# Incorrect intermediate server configuration.
INVALIDPARAMETER_CDNHOSTINVALIDMIDDLECONFIG = 'InvalidParameter.CdnHostInvalidMiddleConfig'

# Invalid domain name format. Please check and try again.
INVALIDPARAMETER_CDNHOSTINVALIDPARAM = 'InvalidParameter.CdnHostInvalidParam'

# Invalid domain name status.
INVALIDPARAMETER_CDNHOSTINVALIDSTATUS = 'InvalidParameter.CdnHostInvalidStatus'

# Internal API error. Please submit a ticket for troubleshooting.
INVALIDPARAMETER_CDNINTERFACEERROR = 'InvalidParameter.CdnInterfaceError'

# Parameter error: Interval. Please check and try again.
INVALIDPARAMETER_CDNINVALIDPARAMINTERVAL = 'InvalidParameter.CdnInvalidParamInterval'

# Parameter error: Metric. Please check and try again.
INVALIDPARAMETER_CDNINVALIDPARAMMETRIC = 'InvalidParameter.CdnInvalidParamMetric'

# Invalid field: ServiceType. Please check and try again.
INVALIDPARAMETER_CDNINVALIDPARAMSERVICETYPE = 'InvalidParameter.CdnInvalidParamServiceType'

# The configuration is not supported.
INVALIDPARAMETER_CDNKEYRULESEXCLUDECUSTOMREQUIRESFULLLEGO = 'InvalidParameter.CdnKeyRulesExcludeCustomRequiresFullLego'

# Invalid field: QueryString. Please check and try again.
INVALIDPARAMETER_CDNKEYRULESINVALIDQUERYSTRINGVALUE = 'InvalidParameter.CdnKeyRulesInvalidQueryStringValue'

# Parameter error. Please see the sample parameters in the documentation.
INVALIDPARAMETER_CDNPARAMERROR = 'InvalidParameter.CdnParamError'

# Cache purge does not support wildcard domain names.
INVALIDPARAMETER_CDNPURGEWILDCARDNOTALLOWED = 'InvalidParameter.CdnPurgeWildcardNotAllowed'

# Prefetch does not support wildcard domain names.
INVALIDPARAMETER_CDNPUSHWILDCARDNOTALLOWED = 'InvalidParameter.CdnPushWildcardNotAllowed'

# Invalid date. Please see the sample date in the documentation.
INVALIDPARAMETER_CDNSTATINVALIDDATE = 'InvalidParameter.CdnStatInvalidDate'

# Invalid statistical dimension. Please see the sample statistical analysis in the documentation.
INVALIDPARAMETER_CDNSTATINVALIDFILTER = 'InvalidParameter.CdnStatInvalidFilter'

# Invalid statistical type. Please see the sample statistical analysis in the documentation.
INVALIDPARAMETER_CDNSTATINVALIDMETRIC = 'InvalidParameter.CdnStatInvalidMetric'

# Incorrect project ID. Please check and try again.
INVALIDPARAMETER_CDNSTATINVALIDPROJECTID = 'InvalidParameter.CdnStatInvalidProjectId'

# The number of queried domain names reached the limit.
INVALIDPARAMETER_CDNSTATTOOMANYDOMAINS = 'InvalidParameter.CdnStatTooManyDomains'

# The URL exceeds the length limit.
INVALIDPARAMETER_CDNURLEXCEEDLENGTH = 'InvalidParameter.CdnUrlExceedLength'

# Index conflict.
INVALIDPARAMETER_CLSINDEXCONFLICT = 'InvalidParameter.ClsIndexConflict'

# The index rule is empty.
INVALIDPARAMETER_CLSINDEXRULEEMPTY = 'InvalidParameter.ClsIndexRuleEmpty'

# Invalid content.
INVALIDPARAMETER_CLSINVALIDCONTENT = 'InvalidParameter.ClsInvalidContent'

# Invalid `Content-Type`.
INVALIDPARAMETER_CLSINVALIDCONTENTTYPE = 'InvalidParameter.ClsInvalidContentType'

# Parameter error. Please check and try again.
INVALIDPARAMETER_CLSINVALIDPARAM = 'InvalidParameter.ClsInvalidParam'

# Logset conflict.
INVALIDPARAMETER_CLSLOGSETCONFLICT = 'InvalidParameter.ClsLogsetConflict'

# The logset is empty.
INVALIDPARAMETER_CLSLOGSETEMPTY = 'InvalidParameter.ClsLogsetEmpty'

# The logset is not empty.
INVALIDPARAMETER_CLSLOGSETNOTEMPTY = 'InvalidParameter.ClsLogsetNotEmpty'

# No authorization information.
INVALIDPARAMETER_CLSMISSINGAUTHORIZATION = 'InvalidParameter.ClsMissingAuthorization'

# Lost content.
INVALIDPARAMETER_CLSMISSINGCONTENT = 'InvalidParameter.ClsMissingContent'

# Syntax error.
INVALIDPARAMETER_CLSSYNTAXERROR = 'InvalidParameter.ClsSyntaxError'

# The topic has been closed.
INVALIDPARAMETER_CLSTOPICCLOSED = 'InvalidParameter.ClsTopicClosed'

# Topic conflict.
INVALIDPARAMETER_CLSTOPICCONFLICT = 'InvalidParameter.ClsTopicConflict'

# API internal error. Please try again or contact the customer service for assistance.
INVALIDPARAMETER_ECDNINTERFACEERROR = 'InvalidParameter.EcdnInterfaceError'

# The maximum number of regex sub-patterns is exceeded.
INVALIDPARAMETER_PATHREGEXTOOMANYSUBPATTERN = 'InvalidParameter.PathRegexTooManySubPattern'

# This platform does not support remote authentication.
INVALIDPARAMETER_REMOTEAUTHINVALIDPLATFORM = 'InvalidParameter.RemoteAuthInvalidPlatform'

# This platform does not support remote access to an authentication address via the HTTPS protocol.
INVALIDPARAMETER_REMOTEAUTHINVALIDPROTOCOL = 'InvalidParameter.RemoteAuthInvalidProtocol'

# Unable to recreate: the task has expired.
INVALIDPARAMETER_SCDNLOGTASKEXPIRED = 'InvalidParameter.ScdnLogTaskExpired'

# The task does not exist or was not failed.
INVALIDPARAMETER_SCDNLOGTASKNOTFOUNDORNOTFAIL = 'InvalidParameter.ScdnLogTaskNotFoundOrNotFail'

# Incorrect time range
INVALIDPARAMETER_SCDNLOGTASKTIMERANGEINVALID = 'InvalidParameter.ScdnLogTaskTimeRangeInvalid'

# Too frequent queries on IP ownership.
LIMITEXCEEDED_CDNCALLINGQUERYIPTOOOFTEN = 'LimitExceeded.CdnCallingQueryIpTooOften'

# This account has created too many topics.
LIMITEXCEEDED_CDNCLSTOOMANYTOPICS = 'LimitExceeded.CdnClsTooManyTopics'

# The number of cache validity configuration rules exceeds the limit.
LIMITEXCEEDED_CDNCONFIGTOOMANYCACHERULES = 'LimitExceeded.CdnConfigTooManyCacheRules'

# Domain name operations are too frequent.
LIMITEXCEEDED_CDNHOSTOPTOOOFTEN = 'LimitExceeded.CdnHostOpTooOften'

# The number of directories to be purged exceeds the limit.
LIMITEXCEEDED_CDNPURGEPATHEXCEEDBATCHLIMIT = 'LimitExceeded.CdnPurgePathExceedBatchLimit'

# The number of directories to be purged exceeds the daily limit.
LIMITEXCEEDED_CDNPURGEPATHEXCEEDDAYLIMIT = 'LimitExceeded.CdnPurgePathExceedDayLimit'

# The number of URLs to be purged exceeds the limit.
LIMITEXCEEDED_CDNPURGEURLEXCEEDBATCHLIMIT = 'LimitExceeded.CdnPurgeUrlExceedBatchLimit'

# The number of URLs to be purged exceeds the daily limit.
LIMITEXCEEDED_CDNPURGEURLEXCEEDDAYLIMIT = 'LimitExceeded.CdnPurgeUrlExceedDayLimit'

# The number of URLs to be prefetched at a time exceeds the limit.
LIMITEXCEEDED_CDNPUSHEXCEEDBATCHLIMIT = 'LimitExceeded.CdnPushExceedBatchLimit'

# The number of URLs to be prefetched exceeds the daily limit.
LIMITEXCEEDED_CDNPUSHEXCEEDDAYLIMIT = 'LimitExceeded.CdnPushExceedDayLimit'

# The number of IPs to be queried exceeds the limit.
LIMITEXCEEDED_CDNQUERYIPBATCHTOOMANY = 'LimitExceeded.CdnQueryIpBatchTooMany'

# The log size exceeds the limit.
LIMITEXCEEDED_CLSLOGSIZEEXCEED = 'LimitExceeded.ClsLogSizeExceed'

# The number of logsets exceeds the limit.
LIMITEXCEEDED_CLSLOGSETEXCEED = 'LimitExceeded.ClsLogsetExceed'

# The number of topics exceeds the limit.
LIMITEXCEEDED_CLSTOPICEXCEED = 'LimitExceeded.ClsTopicExceed'

# Daily task quota exceeded
LIMITEXCEEDED_SCDNLOGTASKEXCEEDDAYLIMIT = 'LimitExceeded.ScdnLogTaskExceedDayLimit'

# Domain name already exists.
RESOURCEINUSE_CDNHOSTEXISTS = 'ResourceInUse.CdnHostExists'

# CDN resources are being operated.
RESOURCEINUSE_CDNOPINPROGRESS = 'ResourceInUse.CdnOpInProgress'

# Unable to find the domain name. Please make sure the domain name is correct.
RESOURCENOTFOUND_CDNHOSTNOTEXISTS = 'ResourceNotFound.CdnHostNotExists'

# The project does not exist. Please check and try again.
RESOURCENOTFOUND_CDNPROJECTNOTEXISTS = 'ResourceNotFound.CdnProjectNotExists'

# The CDN service has not been activated. Please activate it first before using this API.
RESOURCENOTFOUND_CDNUSERNOTEXISTS = 'ResourceNotFound.CdnUserNotExists'

# The number of domain names under the account has reached the upper limit. Please submit a ticket for assistance.
RESOURCENOTFOUND_CDNUSERTOOMANYHOSTS = 'ResourceNotFound.CdnUserTooManyHosts'

# The index does not exist.
RESOURCENOTFOUND_CLSINDEXNOTEXIST = 'ResourceNotFound.ClsIndexNotExist'

# The logset does not exist.
RESOURCENOTFOUND_CLSLOGSETNOTEXIST = 'ResourceNotFound.ClsLogsetNotExist'

# The topic does not exist.
RESOURCENOTFOUND_CLSTOPICNOTEXIST = 'ResourceNotFound.ClsTopicNotExist'

# The domain name does not exist. Please check and try again.
RESOURCENOTFOUND_ECDNDOMAINNOTEXISTS = 'ResourceNotFound.EcdnDomainNotExists'

# The domain name has been connected to the Mainland China service region. If you need to switch the service region to "Global", please verify its ownership for domain name retrieval.
RESOURCEUNAVAILABLE_CDNHOSTBELONGSTOOTHERSINMAINLAND = 'ResourceUnavailable.CdnHostBelongsToOthersInMainland'

# The domain name has been connected to the service region outside Mainland China. If you need to switch the service region to "Global", please verify its ownership for domain name retrieval.
RESOURCEUNAVAILABLE_CDNHOSTBELONGSTOOTHERSINOVERSEAS = 'ResourceUnavailable.CdnHostBelongsToOthersInOverseas'

# The domain name is locked.
RESOURCEUNAVAILABLE_CDNHOSTISLOCKED = 'ResourceUnavailable.CdnHostIsLocked'

# Domain name is still in use.
RESOURCEUNAVAILABLE_CDNHOSTISNOTOFFLINE = 'ResourceUnavailable.CdnHostIsNotOffline'

# The domain name has been deactivated. Prefetch requests cannot be submitted.
RESOURCEUNAVAILABLE_CDNHOSTISNOTONLINE = 'ResourceUnavailable.CdnHostIsNotOnline'

# ICP filing is required for the domain name and the synchronization takes 2 hours. If it is already filed, please try later.
RESOURCEUNAVAILABLE_CDNHOSTNOICP = 'ResourceUnavailable.CdnHostNoIcp'

# The SCDN service is not activated. Please purchase or renew an SCDN packet and try again.
RESOURCEUNAVAILABLE_SCDNUSERNOPACKAGE = 'ResourceUnavailable.ScdnUserNoPackage'

# The sub-account is unauthorized to query full data.
UNAUTHORIZEDOPERATION_CDNACCOUNTUNAUTHORIZED = 'UnauthorizedOperation.CdnAccountUnauthorized'

# No CAM policy is configured for the sub-account.
UNAUTHORIZEDOPERATION_CDNCAMUNAUTHORIZED = 'UnauthorizedOperation.CdnCamUnauthorized'

# This account is not authorized to activate CLS.
UNAUTHORIZEDOPERATION_CDNCLSNOTREGISTERED = 'UnauthorizedOperation.CdnClsNotRegistered'

# The domain name is not compliant and cannot be connected.
UNAUTHORIZEDOPERATION_CDNHOSTINICPBLACKLIST = 'UnauthorizedOperation.CdnHostInIcpBlacklist'

# The domain name has been connected by another account. For more information, please submit a ticket.
UNAUTHORIZEDOPERATION_CDNHOSTISUSEDBYOTHER = 'UnauthorizedOperation.CdnHostIsUsedByOther'

# The sub-account has no access to the CDN-accelerated domain name.
UNAUTHORIZEDOPERATION_CDNHOSTUNAUTHORIZED = 'UnauthorizedOperation.CdnHostUnauthorized'

# The project is not authorized for the sub-account.
UNAUTHORIZEDOPERATION_CDNPROJECTUNAUTHORIZED = 'UnauthorizedOperation.CdnProjectUnauthorized'

# The sub-account has no access to the tag.
UNAUTHORIZEDOPERATION_CDNTAGUNAUTHORIZED = 'UnauthorizedOperation.CdnTagUnauthorized'

# Fail to authenticate the CDN user.
UNAUTHORIZEDOPERATION_CDNUSERAUTHFAIL = 'UnauthorizedOperation.CdnUserAuthFail'

# The CDN user is pending authentication.
UNAUTHORIZEDOPERATION_CDNUSERAUTHWAIT = 'UnauthorizedOperation.CdnUserAuthWait'

# Service internal error. Please submit a ticket for troubleshooting.
UNAUTHORIZEDOPERATION_CDNUSERINVALIDCREDENTIAL = 'UnauthorizedOperation.CdnUserInvalidCredential'

# The account has been isolated due to arrears. Please pay the bill and try again.
UNAUTHORIZEDOPERATION_CDNUSERISISOLATED = 'UnauthorizedOperation.CdnUserIsIsolated'

# The CDN service has been suspended. Please restart it and try again.
UNAUTHORIZEDOPERATION_CDNUSERISSUSPENDED = 'UnauthorizedOperation.CdnUserIsSuspended'

# You are not in the beta whitelist and thus have no permission to use this function.
UNAUTHORIZEDOPERATION_CDNUSERNOWHITELIST = 'UnauthorizedOperation.CdnUserNoWhitelist'

# Invalid authorization.
UNAUTHORIZEDOPERATION_CLSINVALIDAUTHORIZATION = 'UnauthorizedOperation.ClsInvalidAuthorization'

# You have not activated CLS service. Please activate it in the CLS console first.
UNAUTHORIZEDOPERATION_CLSSERVICENOTACTIVATED = 'UnauthorizedOperation.ClsServiceNotActivated'

# Authorization failed.
UNAUTHORIZEDOPERATION_CLSUNAUTHORIZED = 'UnauthorizedOperation.ClsUnauthorized'

# Service internal error. Please submit a ticket for troubleshooting.
UNAUTHORIZEDOPERATION_CSRFERROR = 'UnauthorizedOperation.CsrfError'

# Please go to the CDN console for operation.
UNAUTHORIZEDOPERATION_ECDNMIGRATEDCDN = 'UnauthorizedOperation.EcdnMigratedCdn'

# This operation is not supported currently. Please submit a ticket for assistance.
UNAUTHORIZEDOPERATION_OPNOAUTH = 'UnauthorizedOperation.OpNoAuth'

# Too many calling attempts.
UNAUTHORIZEDOPERATION_OPERATIONTOOOFTEN = 'UnauthorizedOperation.OperationTooOften'

# The operation is not allowed.
UNSUPPORTEDOPERATION_CLSNOTALLOWED = 'UnsupportedOperation.ClsNotAllowed'

# This operation is not supported currently. Please submit a ticket for assistance.
UNSUPPORTEDOPERATION_OPNOAUTH = 'UnsupportedOperation.OpNoAuth'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# The operation failed.
FAILEDOPERATION = 'FailedOperation'

# The domain is already in your list. There is no need to add it again.
FAILEDOPERATION_DOMAINEXISTS = 'FailedOperation.DomainExists'

# This domain is a key protected resource in DNSPod. To prevent the service from being affected by maloperations, you cannot delete it. If you are sure you need to delete it, please contact your sales rep for technical support.
FAILEDOPERATION_DOMAINISKEYDOMAIN = 'FailedOperation.DomainIsKeyDomain'

# You cannot perform this operation on a locked domain.
FAILEDOPERATION_DOMAINISLOCKED = 'FailedOperation.DomainIsLocked'

# You cannot perform this operation on a banned domain.
FAILEDOPERATION_DOMAINISSPAM = 'FailedOperation.DomainIsSpam'

# You cannot perform this operation on a VIP domain.
FAILEDOPERATION_DOMAINISVIP = 'FailedOperation.DomainIsVip'

# This domain has been added by another account and can be reclaimed in the domain list.
FAILEDOPERATION_DOMAINOWNEDBYOTHERUSER = 'FailedOperation.DomainOwnedByOtherUser'

# The request was rejected due to an unusual login location of your account.
FAILEDOPERATION_LOGINAREANOTALLOWED = 'FailedOperation.LoginAreaNotAllowed'

# Login failed. Check whether the account and password are correct.
FAILEDOPERATION_LOGINFAILED = 'FailedOperation.LoginFailed'

# The operation has no response. Try again later.
FAILEDOPERATION_UNKNOWERROR = 'FailedOperation.UnknowError'

# Your account is banned by the system. Please contact us if you have any questions.
INVALIDPARAMETER_ACCOUNTISBANNED = 'InvalidParameter.AccountIsBanned'

# Custom error message.
INVALIDPARAMETER_CUSTOMMESSAGE = 'InvalidParameter.CustomMessage'

# DNSSEC has been enabled for this domain. You cannot add an @CNAME, URL, or framed URL record.
INVALIDPARAMETER_DNSSECADDCNAMEERROR = 'InvalidParameter.DnssecAddCnameError'

# The domain number is incorrect.
INVALIDPARAMETER_DOMAINIDINVALID = 'InvalidParameter.DomainIdInvalid'

# You cannot perform operations on a domain currently active or invalid.
INVALIDPARAMETER_DOMAININEFFECTORINVALIDATED = 'InvalidParameter.DomainInEffectOrInvalidated'

# The domain is incorrect. Enter a top-level domain such as dnspod.cn.
INVALIDPARAMETER_DOMAININVALID = 'InvalidParameter.DomainInvalid'

# This domain is an alias of another domain.
INVALIDPARAMETER_DOMAINISALIASER = 'InvalidParameter.DomainIsAliaser'

# You cannot change the DNS record of a domain currently active or invalid.
INVALIDPARAMETER_DOMAINNOTALLOWEDMODIFYRECORDS = 'InvalidParameter.DomainNotAllowedModifyRecords'

# The domain does not have an ICP filing, so you cannot add a URL record for it.
INVALIDPARAMETER_DOMAINNOTBEIAN = 'InvalidParameter.DomainNotBeian'

# The domain has not been registered and cannot be added.
INVALIDPARAMETER_DOMAINNOTREGED = 'InvalidParameter.DomainNotReged'

# The record already exists and does not need to be added again.
INVALIDPARAMETER_DOMAINRECORDEXIST = 'InvalidParameter.DomainRecordExist'

# Sorry, the email address of your account has not been verified.
INVALIDPARAMETER_EMAILNOTVERIFIED = 'InvalidParameter.EmailNotVerified'

# The weight is invalid. Enter an integer between 0 and 100.
INVALIDPARAMETER_INVALIDWEIGHT = 'InvalidParameter.InvalidWeight'

# The token ID is incorrect.
INVALIDPARAMETER_LOGINTOKENIDERROR = 'InvalidParameter.LoginTokenIdError'

# The token passed in does not exist.
INVALIDPARAMETER_LOGINTOKENNOTEXISTS = 'InvalidParameter.LoginTokenNotExists'

# Failed to verify the token.
INVALIDPARAMETER_LOGINTOKENVALIDATEFAILED = 'InvalidParameter.LoginTokenValidateFailed'

# Sorry, the mobile number of your account has not been verified.
INVALIDPARAMETER_MOBILENOTVERIFIED = 'InvalidParameter.MobileNotVerified'

# The MX priority is incorrect.
INVALIDPARAMETER_MXINVALID = 'InvalidParameter.MxInvalid'

# The record number is incorrect.
INVALIDPARAMETER_RECORDIDINVALID = 'InvalidParameter.RecordIdInvalid'

# The record split zone is incorrect.
INVALIDPARAMETER_RECORDLINEINVALID = 'InvalidParameter.RecordLineInvalid'

# The record type is incorrect.
INVALIDPARAMETER_RECORDTYPEINVALID = 'InvalidParameter.RecordTypeInvalid'

# The record value is incorrect.
INVALIDPARAMETER_RECORDVALUEINVALID = 'InvalidParameter.RecordValueInvalid'

# The DNS record value is too long.
INVALIDPARAMETER_RECORDVALUELENGTHINVALID = 'InvalidParameter.RecordValueLengthInvalid'

# The remarks are too long (max 200 characters).
INVALIDPARAMETER_REMARKTOOLONG = 'InvalidParameter.RemarkTooLong'

# Your IP is invalid, so the request was rejected.
INVALIDPARAMETER_REQUESTIPLIMITED = 'InvalidParameter.RequestIpLimited'

# The subdomain is incorrect.
INVALIDPARAMETER_SUBDOMAININVALID = 'InvalidParameter.SubdomainInvalid'

# The domain is invalid.
INVALIDPARAMETER_TOOLSDOMAININVALID = 'InvalidParameter.ToolsDomainInvalid'

# Your account identity has not been verified. Complete identity verification first before performing this operation.
INVALIDPARAMETER_UNREALNAMEUSER = 'InvalidParameter.UnrealNameUser'

# Sorry, the URL failed to be added/enabled because its content did not comply with the DNSPod Terms of Service. Please contact technical support for assistance.
INVALIDPARAMETER_URLVALUEILLEGAL = 'InvalidParameter.UrlValueIllegal'

# The user does not exist.
INVALIDPARAMETER_USERNOTEXISTS = 'InvalidParameter.UserNotExists'

# The current domain is incorrect. Return to the previous step and try again.
INVALIDPARAMETERVALUE_DOMAINNOTEXISTS = 'InvalidParameterValue.DomainNotExists'

# The user number is incorrect.
INVALIDPARAMETERVALUE_USERIDINVALID = 'InvalidParameterValue.UserIdInvalid'

# The number of AAAA records exceeds the limit.
LIMITEXCEEDED_AAAACOUNTLIMIT = 'LimitExceeded.AAAACountLimit'

# The @NS record can be set to the default split zone only.
LIMITEXCEEDED_ATNSRECORDLIMIT = 'LimitExceeded.AtNsRecordLimit'

# Your account has been banned by the system due to excessive failed login attempts.
LIMITEXCEEDED_FAILEDLOGINLIMITEXCEEDED = 'LimitExceeded.FailedLoginLimitExceeded'

# The DNS plan used by this domain does not support framed URL forwarding, or the number of framed URL forward records exceeds the limit. To use this feature, please purchase more records.
LIMITEXCEEDED_HIDDENURLEXCEEDED = 'LimitExceeded.HiddenUrlExceeded'

# The number of NS records exceeds the limit.
LIMITEXCEEDED_NSCOUNTLIMIT = 'LimitExceeded.NsCountLimit'

# The TTL value of the record exceeds the limit.
LIMITEXCEEDED_RECORDTTLLIMIT = 'LimitExceeded.RecordTtlLimit'

# The number of SRV records exceeds the limit.
LIMITEXCEEDED_SRVCOUNTLIMIT = 'LimitExceeded.SrvCountLimit'

# The number of subdomain levels exceeds the limit.
LIMITEXCEEDED_SUBDOMAINLEVELLIMIT = 'LimitExceeded.SubdomainLevelLimit'

# The number of round-robin DNS records of the subdomain exceeds the limit.
LIMITEXCEEDED_SUBDOMAINROLLLIMIT = 'LimitExceeded.SubdomainRollLimit'

# The number of wildcard levels exceeds the limit.
LIMITEXCEEDED_SUBDOMAINWCARDLIMIT = 'LimitExceeded.SubdomainWcardLimit'

# The number of URL forward records of this domain exceeds the limit. To continue using this feature, please purchase more records.
LIMITEXCEEDED_URLCOUNTLIMIT = 'LimitExceeded.UrlCountLimit'

# Only the domain owner can perform this operation.
OPERATIONDENIED_DOMAINOWNERALLOWEDONLY = 'OperationDenied.DomainOwnerAllowedOnly'

# Sorry, you cannot add a blocked IP.
OPERATIONDENIED_IPINBLACKLISTNOTALLOWED = 'OperationDenied.IPInBlacklistNotAllowed'

# You have no permission to perform operations on the current domain. Return to the domain list.
OPERATIONDENIED_NOPERMISSIONTOOPERATEDOMAIN = 'OperationDenied.NoPermissionToOperateDomain'

# You are not an admin.
OPERATIONDENIED_NOTADMIN = 'OperationDenied.NotAdmin'

# Your are not a proxy user.
OPERATIONDENIED_NOTAGENT = 'OperationDenied.NotAgent'

# The user is not under your account.
OPERATIONDENIED_NOTMANAGEDUSER = 'OperationDenied.NotManagedUser'

# The number of API requests exceeds the limit.
REQUESTLIMITEXCEEDED_REQUESTLIMITEXCEEDED = 'RequestLimitExceeded.RequestLimitExceeded'
